<?php
/**
 * Helper created for functions which can be used at any place in the project
 * @author Vishal Singh <vishal.singh@hashstudioz.com>
 */
    use App\Models\Category;
    use App\Models\SubCategory;
    use Illuminate\Support\Facades\Auth;
    use App\Models\User;
    use App\Models\Brand;
    use App\Models\ProductGallery;
    use App\Models\ProductVariant;
    use App\Models\Product;
    use App\Models\Wishlist;
    use App\Models\Settings;
    use App\Models\VariantAttribute;
    use App\Models\Attribute;
    use App\Models\Cart;
    use Carbon\Carbon;

    function dateConvertFormat($date)
    {
        return date('d-m-Y', strtotime($date));
    }

    // get the title of the category
    function categoryTitle(String $category)
    {
        $categoryIds = json_decode($category,true);
        $title = Category::whereIn('id',$categoryIds)->pluck('title')->toArray();
        $title = implode(', ',$title);
        return $title;
    }

     // get the title of the brand
     function brandTitle($brand_id)
     {
         $title = Brand::where('id',$brand_id)->pluck('title')->first();
         return $title;
     }

    function is_admin(){
        if (Auth::guard('admin')->user() && in_array(Auth::guard('admin')->user()->role,[User::IS_SUP_ADMIN,User::IS_ADMIN])) {
            return true;
        }
        return false;
    }
    if (!function_exists('checkLogin')) {
        function checkLogin(){
            if (Auth::check() || Auth::guard('admin')->check()) {
                return true;
            }
            return false;
        }
    }

    if (!function_exists('aboutUsList')) {
        function aboutUsList(){
            $model = new App\Models\Page;
            $locale = \Lang::getLocale();
            $title = ($locale == 'ar')?'arabic_title':'title';
            $pages = $model->select('slug',"$title as title",'id')->get();
            return $pages;
        }
    }

    //Shop listing
    if (!function_exists('shopList')) {
        function shopList(){
            $locale = \Lang::getLocale();
            $data=[];
            $title = ($locale == 'ar')?'arabic_title':'title';
            $categories = Category::where('status',1)->select('title as key',"$title as title",'id')->take(3)->get();
            $product = Product::select('id','sub_category_id')->where('status',1)->where('created_at', '>=', Carbon::now()->subMonth(2));
            foreach ($categories as  $value) {
                $subCat=[];
                // new arival sub category
                $query = clone $product;
                $pro = $query->where('category_id','like','%"'.$value->id.'"%')->get();
                foreach ($pro as  $p) {
                    $subCat = array_merge($subCat,$p->sub_category_id?json_decode($p->sub_category_id,true):[]);
                }
                $data[$value->title]['id']=$value->id;
                $data[$value->title]['newArrival'] = SubCategory::select('title as key',"$title as title",'id')->whereIn('id',array_unique($subCat))->get();
                // end
                $data[$value->title]['subCategories'] = SubCategory::where('status',1)->select("$title as title",'id')->where('category_id',$value->id)->get();
                $data[$value->title]['brands'] = Brand::select('id',"$title as title")->where('status',1)->get();
            }
            return $data;
        }
    }

    // product
    if (! function_exists('productDetail')) {
        function productDetail($id,$variantId=null,$attr=null,$attrVal=null){
            $data = [];
            $data['attributes']=[];
            $data['variant']=[];
            if($variantId){
                $data['variant'] = ProductVariant::where([
                    'product_id' => $id,
                    'id' => $variantId
                ])->select('price','special_price','currency','id')->first();
                if($attr && $attrVal){
                    $data['attributes'] = VariantAttribute::where([
                        'product_id' => $id,
                        'variant_id' => $variantId
                    ])->whereIn('attribute_id',json_decode($attr,true))->whereIn('attribute_val_id',json_decode($attrVal,true))->select('attribute_id','attribute_val_id')->take(2)->get();
                }
            }
            $data['product'] = Product::where('id',$id)->first();
            $data['image'] = ProductGallery::where('product_id',$id)->value('image');
            return $data;
        }
    }

    // product
    if (! function_exists('authUser')) {
        function authUser(){
            return is_admin()?auth()->guard('admin'):auth();
        }
    }

     // product
     if (! function_exists('checkWishlist')) {
        function checkWishlist($pid,$vid){
            if(checkLogin()){
                $check = Wishlist::where([
                    'user_id' => authUser()->user()->id,
                    'product_id' => $pid,
                    'variant_id'=> $vid
                ])->first();
            }
            return !empty($check)?1:0;
        }
    }

    // Setting Data
    if (! function_exists('settingData')) {
        function settingData($attr=null){
            if($attr == 'contact'){
                $data = Settings::select('contact_us_email','contact_us_phone','contact_us_address')->first();
            }else{
                $data = Settings::first();
            }
            return $data;
        }
    }

    // Get Product price
    if (! function_exists('productPrice')) {
        function productPrice($variantId,$withCurrency =false,$quantity=1){
            $variant =ProductVariant::where('id',$variantId)->first();
            $price = $variant->price;
            if($variant->special_price){
                $price = $variant->special_price;
            }
            $price *= $quantity;
            return $withCurrency?$variant->currency.' '.$price:$price;
        }
    }

    // Transfer Cart Items
    if (! function_exists('transferCartItem')) {
        function transferCartItem(){
            \DB::beginTransaction();
            try {
                $cart = Cart::where([
                    'user_id'=> 0,
                    'user_ip'=> \Request::ip()
                ])->get();
                foreach ($cart as $cartItem) {
                    $check = Cart::where([
                        'user_id' => authUser()->user()->id,
                        'product_id' => $cartItem->product_id,
                        'variant_id'=> $cartItem->variant_id
                    ])->first();

                    if($check){
                        $check->quantity+=$cartItem->quantity;
                        $check->save();
                        $cartItem->delete();
                    }else{
                        $cartItem->user_id = authUser()->user()->id;
                        $cartItem->save();
                    }
                }
                \DB::commit();
            } catch (\Exception $e) {
                \DB::rollback();
                return response()->json([
                    'error' => __('Something went wrong, please try again')
                ]);
            }
        }
    }

     // Get Product price
     if (! function_exists('grandTotal')) {
        function grandTotal($total,$shippingCost=null,$taxPrcnt=0){
            if(empty($taxPrcnt) || (empty($shippingCost) && $shippingCost!=0)){
                $setting = settingData();
                $taxPrcnt = $taxPrcnt ? $taxPrcnt: $setting->tax_prcnt??0;
                $shippingCost = ($shippingCost ||  $shippingCost==0) ? $shippingCost : $setting->default_shipping_cost??0;
            }
            $taxPrcnt = ($total * $taxPrcnt)/100;

            return $total + $shippingCost + $taxPrcnt;
        }
    }

    // Get Carts Products
    if (! function_exists('getCartProducts')) {
        function getCartProducts($id=null){
            if(checkLogin()){
                $cart = Cart::where('user_id',authUser()->user()->id);
            }else{
                $cart = Cart::where([
                    'user_id'=> 0,
                    'user_ip'=>\Request::ip()
                    ]);
            }
            if($id){
                $cart = $cart->where('product_id',$id);
            }
            return $cart->get();
        }
    }

    // Attributes
    if (! function_exists('attributeValues')) {
        function attributeValues($attribute){
            $attribute = Attribute::where('title',$attribute)->first();
            return $attribute?$attribute->AttributeValue:[];
        }
    }

?>
