<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Area;
use App\Models\Governorate;
use App\Http\Requests\AreaFormRequest;
use Validator;
use Session;
use Auth;

class AreaController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:area_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:area_create', ['only' => ['create','store']]);
        $this->middleware('permission:area_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:area_delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $areas = Area::with('governorates')->orderBy('id','desc')->get();
        return view('admin.areas.index',get_defined_vars());
    }

    public function create()
    {
        $governorates = Governorate::where('governorates.status',1)->pluck('governorates.title', 'governorates.id','governorates.arabic_title')->toArray();
        return view('admin.areas.create',get_defined_vars());
    }

    public function store(AreaFormRequest $request)
    {
        $data = new Area;
        $data->governorate_id = $request->get('governorate_id');
        $data->title = $request->get('title');
        $data->arabic_title = $request->get('arabic_title');
        $data->shipping_cost = $request->get('shipping_cost');
        $data->status = $request->get('status');
        $data->save();
        return redirect('admin/areas')->with('success','Record has been created successfully!');
    }

    public function edit(Area $area)
    {
        $area = $area;
        $governorates = Governorate::where('governorates.status',1)->pluck('governorates.title', 'governorates.id','governorates.arabic_title')->toArray();
        return view('admin.areas.edit',get_defined_vars());
    }

    public function update(AreaFormRequest $request,$area_id)
    {
        $area = Area::find($area_id);
        $area->title = $request->get('title');
        $area->arabic_title = $request->get('arabic_title');
        $area->shipping_cost = $request->get('shipping_cost');
        $area->status = $request->get('status');
        $area->save();

        // redirect
        return redirect('admin/areas')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, Area $area)
    {
        $id = $area->id;
        $data = Area::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $area = Area::where('id',$id)->first();
        if($area->status=='1'){
            Area::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Area::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/areas')->with('success','Status has been updated successfully!');
    }
}
