<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Attribute;
use App\Http\Requests\AttributeFormRequest;
use Validator;
use Session;
use Auth;
use Illuminate\Support\Str;

class AttributeController extends Controller
{
   /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {
        $this->middleware('adminauth');
        $this->middleware('permission:attribute_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:attribute_create', ['only' => ['create','store']]);
        $this->middleware('permission:attribute_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:attribute_delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $attributes = Attribute::orderBy('id','desc')->get();
        return view('admin.attributes.index',get_defined_vars());
    }

    public function create()
    {
        return view('admin.attributes.create',get_defined_vars());
    }

    public function store(AttributeFormRequest $request)
    {
        $data = new Attribute;
        $data->title = $request->get('title');
        $data->arabic_title = $request->get('arabic_title');
        $data->status = $request->get('status');
        $data->save();

        return redirect('admin/attributes')->with('success','Record has been created successfully!');
    }

    public function edit(Attribute $attribute)
    {
        $attribute = $attribute;
        return view('admin.attributes.edit',get_defined_vars());
    }

    public function update(AttributeFormRequest $request,$attribute_id)
    {
        //update the record
        $attribute = Attribute::find($attribute_id);

        $attribute->title = $request->get('title');
        $attribute->arabic_title = $request->get('arabic_title');
        $attribute->status = $request->get('status');
        $attribute->save();
        return redirect('admin/attributes')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, Attribute $attribute)
    {
        $id = $attribute->id;
        $data = Attribute::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $attribute = Attribute::where('id',$id)->first();
        if($attribute->status=='1'){
            Attribute::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Attribute::where('id',$id)->update([
                'status'=>'1'
            ]);
        }
        return redirect('admin/attributes')->with('success','Status has been updated successfully!');
    }
}
