<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\AttributeValue;
use App\Models\Attribute;
use App\Http\Requests\AttributeValueFormRequest;
use Validator;
use Session;
use Auth;
use Illuminate\Support\Str;

class AttributeValueController extends Controller
{
   /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:attribute_value_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:attribute_value_create', ['only' => ['create','store']]);
        $this->middleware('permission:attribute_value_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:attribute_value_delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $attribute_values = AttributeValue::with('attributes')->orderBy('id','desc')->get();
        return view('admin.attribute_values.index',get_defined_vars());
    }

    public function create()
    {
        $attributes = Attribute::where('attributes.status',1)->pluck('attributes.title', 'attributes.id','attributes.arabic_title')->toArray();
        return view('admin.attribute_values.create',get_defined_vars());
    }

    public function store(AttributeValueFormRequest $request)
    {
        $data = new AttributeValue;
        $data->title = $request->get('title');
        $data->attribute_id = $request->get('attribute_id');
        $data->arabic_title = $request->get('arabic_title');
        $data->status = $request->get('status');
        $data->color_code = $request->get('color_code');
        $data->save();

        return redirect('admin/attribute_values')->with('success','Record has been created successfully!');
    }

    public function edit(AttributeValue $attributeValue)
    {
        $attributes = Attribute::where('attributes.status',1)->pluck('attributes.title', 'attributes.id','attributes.arabic_title')->toArray();
        $attribute_value = $attributeValue;
        return view('admin.attribute_values.edit',get_defined_vars());
    }

    public function update(AttributeValueFormRequest $request,$attribute_value_id)
    {
        //update the record
        $attribute_value = AttributeValue::find($attribute_value_id);

        $attribute_value->title = $request->get('title');
        $attribute_value->attribute_id = $request->get('attribute_id');
        $attribute_value->arabic_title = $request->get('arabic_title');
        $attribute_value->status = $request->get('status');
        $attribute_value->color_code = $request->get('color_code');
        $attribute_value->save();
        return redirect('admin/attribute_values')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, AttributeValue $attributeValue)
    {
        $id = $attributeValue->id;
        $data = AttributeValue::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $attributevalue = AttributeValue::where('id',$id)->first();
        if($attributevalue->status=='1'){
            AttributeValue::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            AttributeValue::where('id',$id)->update([
                'status'=>'1'
            ]);
        }
        return redirect('admin/attribute_values')->with('success','Status has been updated successfully!');
    }
}
