<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Banner;
use App\Http\Requests\BannerFormRequest;
use Validator;
use Session;
use Auth;
use Illuminate\Support\Str;

class BannerController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {
        $this->middleware('adminauth');
        $this->middleware('permission:banner_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:banner_create', ['only' => ['create','store']]);
        $this->middleware('permission:banner_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:banner_delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $banners = Banner::orderBy('id','desc')->get();
        return view('admin.banners.index',get_defined_vars());
    }

    public function create()
    {
       return view('admin.banners.create',get_defined_vars());
    }

    public function store(BannerFormRequest $request)
    {
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                return redirect('admin/banner/create')->with('error','Image format must be jpeg,jpg,png');
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/banners_images/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = '';
        }
        $data = new Banner;
        $data->title = $request->get('title');
        $data->arabic_title = $request->get('arabic_title');
        $data->description = $request->get('description');
        $data->arabic_description = $request->get('arabic_description');
        $data->image = $imageData;
        // $data->banner_url = $request->get('banner_url');
        $data->status = $request->get('status');
        $data->save();

        return redirect('admin/banners')->with('success','Record has been created successfully!');
    }

    public function edit(Banner $banner)
    {
        $banner = $banner;
        return view('admin.banners.edit',get_defined_vars());
    }

    public function update(BannerFormRequest $request,$banner_id)
    {
        //update the record
        $banner = Banner::find($banner_id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                return redirect('admin/banner/edit/'.$banner_id)->with('error','Image format must be jpeg,jpg,png');
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/banners_images/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = $banner->image;
        }

            $banner->title = $request->get('title');
            $banner->arabic_title = $request->get('arabic_title');
            $banner->description = $request->get('description');
            $banner->arabic_description = $request->get('arabic_description');
            $banner->image = $imageData;
            // $data->banner_url = $request->get('banner_url');
            $banner->status = $request->get('status');
            $banner->save();
            return redirect('admin/banners')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, Banner $banner)
    {
        $id = $banner->id;
        $data = Banner::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $banner = Banner::where('id',$id)->first();
        if($banner->status=='1'){
            Banner::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Banner::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/banners')->with('success','Status has been updated successfully!');
    }
}
