<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Brand;
use App\Http\Requests\BrandFormRequest;
use Validator;
use Session;
use Auth;
use Illuminate\Support\Str;
use File;

class BrandController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {
        $this->middleware('adminauth');
        $this->middleware('permission:brand_create|brand_view|brand_edit|brand_delete', ['only' => ['index','update_status']]);
        $this->middleware('permission:brand_create', ['only' => ['create','store']]);
        $this->middleware('permission:brand_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:brand_delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $brands = Brand::orderBy('id','desc')->get();
        return view('admin.brands.index',get_defined_vars());
    }

    public function create()
    {
       return view('admin.brands.create',get_defined_vars());
    }

    public function store(BrandFormRequest $request)
    {
        try{
            if ($file = $request->hasFile('image')) {
                $file = $request->file('image');
                $imageType = $file->getClientmimeType();
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/brands_images/';
                $file->move($destinationPath, $fileNameUnique);
                $imageData = $fileNameUnique;
            } else {
                $imageData = '';
            }
            if ($file = $request->hasFile('logo')) {
                $file = $request->file('logo');
                $logoType = $file->getClientmimeType();
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/brands_images/';
                $file->move($destinationPath, $fileNameUnique);
                $logoData = $fileNameUnique;
            } else {
                $logoData = '';
            }
            $data = new Brand;
            $data->title = $request->get('title');
            $data->arabic_title = $request->get('arabic_title');
            $data->slug = Str::slug($request->get('title'));
            $data->logo = $logoData;
            $data->image = $imageData;
            $data->status = $request->get('status');
            $data->save();

            return redirect('admin/brands')->with('success','Record has been created successfully!');
        }catch (\Exception $e) {
            return back()->with('error','Something went wrong! Please try again.');
        }
    }

    public function edit(Brand $brand)
    {
        $brand = $brand;
        return view('admin.brands.edit',get_defined_vars());
    }

    public function update(BrandFormRequest $request,$brand_id)
    {
        //update the record
        $brand = Brand::find($brand_id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            $fileName = $file->getClientOriginalName();
            $fileNameUnique = time() . '_' . $fileName;
            $destinationPath = public_path() . '/brands_images/';
            $file->move($destinationPath, $fileNameUnique);
            $imageData = $fileNameUnique;
        } else {
            $imageData = $brand->image;
        }
        if ($file = $request->hasFile('logo')) {
            $file = $request->file('logo');
            $logoType = $file->getClientmimeType();
            $fileName = $file->getClientOriginalName();
            $fileNameUnique = time() . '_' . $fileName;
            $destinationPath = public_path() . '/brands_images/';
            $file->move($destinationPath, $fileNameUnique);
            $logoData = $fileNameUnique;
        } else {
            $logoData = $brand->logo;
        }
        $brand->title = $request->get('title');
        $brand->arabic_title = $request->get('arabic_title');
        $brand->slug = Str::slug($request->get('title'));
        $brand->logo = $logoData;
        $brand->image = $imageData;
        $brand->status = $request->get('status');
        $brand->save();
        return redirect('admin/brands')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, Brand $brand)
    {
        $id = $brand->id;
        $data = Brand::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $brand = Brand::where('id',$id)->first();
        if($brand->status=='1'){
            Brand::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Brand::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/brands')->with('success','Status has been updated successfully!');
    }

    Public function deleteImage(Request $request){
        $brand = Brand::find($request->id);
        $deleted = false;
        if(!$brand){
            return redirect('admin/brands');
        }
        if($request->type == 'logo'){
            $deleted = $brand->logo;
            $brand->update(['logo' =>  '']);

        } elseif($request->type == 'image') {
            $deleted = $brand->image;
            $brand->update(['image' =>  '']);
        }
        if($deleted){
            $image_path = "/brands_images/".$deleted;  // Value is not URL but directory file path
            if(File::exists($image_path)) {
                File::delete($image_path);
            }
            return back()->with('success','Image/Logo deleted successfully');
        } else {
            return back()->with('error','Unable to deleted Image/Logo');
        }
    }
}
