<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Models\Career;
use App\Models\Job;
use App\Http\Controllers\Controller;

class CareerController extends Controller
{
    public function __construct()

    {
        $this->middleware('adminauth');
    }

    public function index()
    {
        $locale = \Lang::getLocale();
        $title = ($locale == 'ar')?'arabic_title':'title';
        $career = Career::orderBy('id','desc')->get();
        return view('admin.career.index',get_defined_vars());
    }

    public function jobIndex()
    {
        $jobs = Job::orderBy('id','desc')->get();
        return view('admin.career.jobIndex',get_defined_vars());
    }


    public function jobCreate()
    {
       return view('admin.career.jobCreate',get_defined_vars());
    }

    public function jobStore(Request $request)
    {
        try{
           $request->validate([
            'title' => 'required',
            'arabic_title' => 'required',
            'description' => 'required',
            'arabic_description' => 'required',
            'status' => 'required'
           ]);

            $data = new Job;
            $data->title = $request->get('title');
            $data->arabic_title = $request->get('arabic_title');
            $data->description = $request->get('description');
            $data->arabic_description = $request->get('arabic_description');
            $data->status = $request->get('status');
            $data->save();
            return redirect('admin/career/job')->with('success','Record has been created successfully!');
        }catch (\Exception $e) {
            return back()->with('error','Something went wrong! Please try again.');
        }
    }

    public function jobEdit(Request $request)
    {
        $job = Job::find($request->id);
        return view('admin.career.jobEdit',get_defined_vars());
    }

    public function jobUpdate(Request $request,$id)
    {
        //update the record
        $data = Job::find($request->id);
        if(empty($data)){
            return back()->with('error','Something went wrong! Please try again.');
        }
        $request->validate([
            'title' => 'required',
            'arabic_title' => 'required',
            'description' => 'required',
            'arabic_description' => 'required',
            'status' => 'required'
           ]);
        $data->title = $request->get('title');
        $data->arabic_title = $request->get('arabic_title');
        $data->description = $request->get('description');
        $data->arabic_description = $request->get('arabic_description');
        $data->status = $request->get('status');
        $data->save();
        return redirect('admin/career/job')->with('success','Record has been updated successfully!');
    }


    public function jobDestroy(Request $request, Job $job)
    {
        $id = $job->id;
        $data = Job::find($id);
        $data->delete();
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // career destroy
    public function destroy(Request $request, Career $career)
    {
        $id = $career->id;
        $data = Career::find($id);
        unlink(public_path() . '/careers_file/'. $data->file);
        $data->delete();
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

     // update status
     public function update_status($id){
        $job = Job::where('id',$id)->first();
        if($job->status=='1'){
            Job::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Job::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/career/job')->with('success','Status has been updated successfully!');
    }
}
