<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Category;
use App\Http\Requests\CategoryFormRequest;
use Validator;
use Session;
use Auth;
use Illuminate\Support\Str;


class CategoryController extends Controller
{
   /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {

        $this->middleware('adminauth');
        $this->middleware('permission:category_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:category_create', ['only' => ['create','store']]);
        $this->middleware('permission:category_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:category_delete', ['only' => ['destroy']]);

    }
    public function index()
    {
        $categories = Category::orderBy('id','desc')->get();
        return view('admin.categories.index',get_defined_vars());
    }

    public function create()
    {
        // $categories = Category::where('categories.status',1)->pluck('categories.title', 'categories.id','categories.arabic_title')->toArray();
        return view('admin.categories.create',get_defined_vars());
    }

    public function store(CategoryFormRequest $request)
    {
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            // print_r($imageType); die;
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                return redirect('admin/categories/create')->with('error','Image format must be jpeg,jpg,png');
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/categories_images/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = '';
        }
        $data = new Category;
        $data->title = $request->get('title');
        $data->arabic_title = $request->get('arabic_title');
        $data->slug = Str::slug($request->get('title'));
        $data->description = $request->get('description');
        $data->arabic_description = $request->get('arabic_description');
        $data->image = $imageData;
        // $data->parent_category_id = $request->get('parent_category_id') ? $request->get('parent_category_id') : 0;
        $data->status = $request->get('status');
        $data->save();

        // redirect
        // Session::flash('message', 'Record has been created successfully!');
        return redirect('admin/categories')->with('success','Record has been created successfully!');
    }

    public function edit(Category $category)
    {
        $category = $category;
        return view('admin.categories.edit',get_defined_vars());
    }

    public function update(CategoryFormRequest $request,$category_id)
    {
        //update the record
        // $category_update = $category;
        $category = Category::find($category_id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            // print_r($imageType); die;
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                return redirect('admin/categories/edit/'.$category_id)->with('error','Image format must be jpeg,jpg,png');
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/categories_images/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = $category->image;
        }

            $category->title = $request->get('title');
            $category->arabic_title = $request->get('arabic_title');
            $category->slug = Str::slug($request->get('title'));
            $category->description = $request->get('description');
            $category->arabic_description = $request->get('arabic_description');
            $category->image = $imageData;
            // $category->parent_category_id = $request->get('parent_category_id') ? $request->get('parent_category_id') : 0;
            $category->status = $request->get('status');
            $category->save();

            // redirect
            // Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/categories')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, Category $category)
    {
        $id = $category->id;
        $data = Category::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        // return redirect('admin/categories');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $category = Category::where('id',$id)->first();
        if($category->status=='1'){
            Category::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Category::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/categories')->with('success','Status has been updated successfully!');
    }

}
