<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Coupon;
use App\Http\Requests\CouponFormRequest;

class CouponController extends Controller
{
    public function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:coupon_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:coupon_create', ['only' => ['create','store']]);
        $this->middleware('permission:coupon_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:coupon_delete', ['only' => ['destroy']]);
    }


    public function index()
    {
        $coupons = Coupon::orderBy('id','desc')->get();
        return view('admin.coupons.index',get_defined_vars());
    }

    public function create()
    {
        return view('admin.coupons.create',get_defined_vars());
    }

    public function store(CouponFormRequest $request)
    {
        $data = new Coupon;
        $data->code = $request->get('code');
        $data->type = $request->get('type');
        $data->amount = $request->get('amount');
        $data->usage_limit = $request->get('usage_limit');
        $data->start_date = $request->get('start_date');
        $data->end_date = $request->get('end_date');
        $data->status = $request->get('status');
        if(!$data->save()){
            return redirect('admin/coupon/create')->with('error','Record not saved !!');
        }
        return redirect('admin/coupons')->with('success','Coupon has been created successfully!');
    }

    public function edit(Coupon $coupon)
    {
        $coupon = $coupon;
        return view('admin.coupons.edit',get_defined_vars());
    }

    public function update(CouponFormRequest $request)
    {
        //update the record
        $data = Coupon::find($request->coupon_id);

        $data->code = $request->get('code');
        $data->type = $request->get('type');
        $data->amount = $request->get('amount');
        $data->usage_limit = $request->get('usage_limit');
        $data->start_date = $request->get('start_date');
        $data->end_date = $request->get('end_date');
        $data->status = $request->get('status');
        if(!$data->save()){
            return redirect('admin/coupon/create')->with('error','Record not saved !!');
        }
        return redirect('admin/coupons')->with('success','Coupon has been updated successfully!');
    }


    public function destroy(Request $request, Coupon $coupon)
    {
        $id = $coupon->id;
        $data = Coupon::find($id);
        $data->delete();
        $response = array('status'=> true, 'msg' => 'Coupon has been deleted successfully!');
        return $response;
    }

    //update status
    public function update_status($id){
        $coupon = Coupon::where('id',$id)->first();
        $status = $coupon->status == '0' ? '1':'0';
        Coupon::where('id',$id)->update([
            'status'=> $status
        ]);

        return redirect('admin/coupons')->with('success','Status has been updated successfully!');
    }
}
