<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\PasswordReset;
use App\Mail\ForgotPasswordMail;
use Mail;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Hash;


class ForgotPasswordController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('admin.guest');
    }

    /**
     * Display the form to request a password reset link.
     *
     * @return \Illuminate\Http\Response
     */
    public function showLinkRequestForm()
    {
        return view('admin.auth.passwords.email');
    }

    public function sendResetLinkEmail(Request $request)
    {
        $userEmail = User::where(['email' => $request->email])->first();
        if(empty($userEmail)){           
            return redirect()->back()->with(['error'=>' We can\'t find a user with this e-mail address.']);
            // return redirect()->back()->with(['success'=>'An email with password reset link has been sent to your provided email address.']);
        }
        $reset_token = Str::uuid()->toString();

        PasswordReset::where('email',$request->email)->delete();
        $PaaswordResetToken = new PasswordReset;
        $PaaswordResetToken->email = $request->email; 
        $PaaswordResetToken->token = $reset_token; 
        $PaaswordResetToken->save();

        // send reset password email
        $data_arr['email'] = $request->email;          
        $data_arr['verification_link'] =  config('app.url') . "admin/password/reset/" . $reset_token . "/" . $request->email;
        try {
            Mail::send(new ForgotPasswordMail($data_arr));
            return redirect()->back()->with(['success'=>'An email with password reset link has been sent to your provided email address.']);
        }catch (\Exception $e) {
            dd($e->getMessage());
            return redirect()->back()->with(['error'=>'Error In sending Email']);
        }

    }


    public function showResetForm(Request $request, $token = null)
    {       
        return view('admin.auth.passwords.reset')->with(
                        ['token' => $token, 'email' => $request->email]
        );
    }

    public function resetPassword(Request $request){
        $email = $request->email;
        $token = $request->token;
        $password = $request->password;
        $confirm_email = $request->confirm_email;
        $validator = $this->validate($request, [
            'password' => 'required',
            'confirm_email' => 'required|same:password',
        ],[
            'password.required' => __('Password is required'),
            'confirm_email.required' => __('Confirm password is required'),
            'confirm_email.same' => __('Confirm password and password must match'),
        ]);        
        $user = User::where('email',$email)->first();  
        $resetPass = PasswordReset::where('email',$email)->where('token',$token)->first();
        if(!empty($resetPass)){
            User::where('email',$email)->update([
                'password' => Hash::make($password)
            ]);
            PasswordReset::where('email',$request->email)->delete();
            return redirect()->route('admin-login-form')->with(['success'=>'Password Changed Successfully']);
        }else{
            return redirect()->back()->with(['error'=>'The link may be invalid or expired']);
        }
    }
}
