<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Governorate;
use App\Http\Requests\GovernorateFormRequest;
use Validator;
use Session;
use Auth;

class GovernorateController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:governorate_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:governorate_create', ['only' => ['create','store']]);
        $this->middleware('permission:governorate_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:governorate_delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $governorates = Governorate::orderBy('id','desc')->get();
        return view('admin.governorates.index',get_defined_vars());
    }

    public function create()
    {
        return view('admin.governorates.create',get_defined_vars());
    }

    public function store(GovernorateFormRequest $request)
    {

        $data = new Governorate;
        $data->title = $request->get('title');
        $data->arabic_title = $request->get('arabic_title');
        $data->status = $request->get('status');
        $data->save();

        return redirect('admin/governorate')->with('success','Record has been created successfully!');
    }

    public function edit(Governorate $governorate)
    {
        $governorate = $governorate;
       return view('admin.governorates.edit',get_defined_vars());
    }

    public function update(GovernorateFormRequest $request,$governorate_id)
    {
        $governorate = Governorate::find($governorate_id);
        $governorate->title = $request->get('title');
        $governorate->arabic_title = $request->get('arabic_title');
        $governorate->status = $request->get('status');
        $governorate->save();
        return redirect('admin/governorate')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, Governorate $governorate)
    {
        $id = $governorate->id;
        $data = Governorate::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $governorate = Governorate::where('id',$id)->first();
        if($governorate->status=='1'){
            Governorate::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Governorate::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/governorate')->with('success','Status has been updated successfully!');
    }
}
