<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use App\Models\NewsLetterSubscriber;

class NewsLetterController extends Controller
{
    //
    use AuthenticatesUsers;

     /**
     * Subscribers
     * @return Renderable
     */
    public function subscribers()
    {
        $subscribers = NewsLetterSubscriber::get();
        return view('admin.newsLetter.subscribers');
    }

    public function subscribersAjax(Request $request){
        $draw = $request->get('draw');
        $start = $request->get("start");
        $rowperpage = $request->get("length"); // total number of rows per page

        $columnIndex_arr = $request->get('order');
        $columnName_arr = $request->get('columns');
        $order_arr = $request->get('order');
        $search_arr = $request->get('search');

        $columnIndex = $columnIndex_arr[0]['column']; // Column index
        $columnName = $columnName_arr[$columnIndex]['data']; // Column name
        $columnSortOrder = $order_arr[0]['dir']; // asc or desc
        $searchValue = $search_arr['value']; // Search value

        $totalRecords = NewsLetterSubscriber::select('count(*) as allcount')->count();
        $totalRecordswithFilter = NewsLetterSubscriber::select('count(*) as allcount')->where('email', 'like', '%' . $searchValue . '%')->count();

        // Get records, also we have included search filter as well
        $records = NewsLetterSubscriber::orderBy($columnName, $columnSortOrder)
        ->where('email', 'like', '%' . $searchValue . '%')
        ->skip($start)
        ->take($rowperpage)
        ->get();

        $data_arr = array();
        // $user = \Auth::user();
        // $roles = $user->getRoleName();
        // dd($roles);
        foreach ($records as $record) {

            // $role->hasPermissionTo('edit articles');
            // $actionHtml = '<li><a class="dropdown-item" href="'.route('product.edit', $record->id).'">Edit</a></li>';
            $actionHtml = '';
            $data_arr[] = array(
                "id" => $record->id,
                "email" => $record->email,
                'action' => ''
            );
        }

        $response = array(
            "draw" => intval($draw),
            "iTotalRecords" => $totalRecords,
            "iTotalDisplayRecords" => $totalRecordswithFilter,
            "aaData" => $data_arr,
        );

        echo json_encode($response);
    }


    public function storeSubscriber(Request $request){
        $request->validate([
            'email' => ['required', 'string', 'max:255']
        ]);

        try{
            $subscriber = NewsLetterSubscriber::create([
                'email' => $request->email,
                'created_by' => authUser()->user()?authUser()->user()->id:''
            ]);

            if($subscriber){
                return redirect('admin/newsletter/subscribers')->with('message','Subscriber added successfully');
            } else {
                return back()->withError('Something went wrong! Please try again.');
            }

        } catch (\Exception $e) {
            return back()->withError('Something went wrong! Please try again.');
        }
    }

    public function addSubscriber(){
        return view('admin.newsLetter.create-subscriber');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Renderable
     */
    public function deleteSubscriber(Request $request)
    {
        $subscriber = NewsLetterSubscriber::findOrFail($request->id);

        if($subscriber->delete()){
            return back()->with('message','Subscriber deleted successfully.');
        } else {
            return back()->with('error','Something went wrong! Please try again.');
        }
    }

}
