<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Page;
use Illuminate\Support\Str;
use Validator;

class PageController extends Controller
{
    public function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:page_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:page_create', ['only' => ['create','store']]);
        $this->middleware('permission:page_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:page_delete', ['only' => ['destroy']]);
    }

    public function index()
    {
        $data = Page::all();
        return view('admin.pages.index',get_defined_vars());
    }

    public function create()
    {
        return view('admin.pages.create');
    }

    public function store(Request $request)
    {
        //validation
        $rules = array(
            'title'       => 'required|unique:pages',
            'arabic_title'       => 'required|unique:pages',
            'arabic_description'       => 'required',
            'description'       => 'required'
        );
        $validator = Validator::make($request->all(), $rules);
        if ($validator->fails()) {
            return redirect('admin/pages/create')
                ->withErrors($validator);
        }else{
            // store
            if ($file = $request->hasFile('image')) {
                $file = $request->file('image');
                $imageType = $file->getClientmimeType();
                // print_r($imageType); die;
                $rules = array(
                    'image' => 'mimes:jpeg,jpg,png',
                );

                $validator = Validator::make($request->all(), $rules);

                if ($validator->fails()) {
                    return redirect('admin/pages/create')->with('error','Image format must be jpeg,jpg,png');
                } else {
                    $fileName = $file->getClientOriginalName();
                    $fileNameUnique = time() . '_' . $fileName;
                    $destinationPath = public_path() . '/page_image/';
                    $file->move($destinationPath, $fileNameUnique);
                }
                $imageData = $fileNameUnique;
            } else {
                $imageData = '';
            }
            $Page = new Page;
            $Page->title = $request->get('title');
            $Page->slug = Str::slug($request->get('title'));
            $Page->arabic_title = $request->get('arabic_title');
            $Page->description = $request->get('description');
            $Page->arabic_description = $request->get('arabic_description');
            $Page->image = $imageData;
            $Page->save();

            // redirect
            return redirect("admin/pages")->with('success','Record has been created successfully!');
        }
    }

    public function edit($id)
    {
        //get record
        $data = Page::find($id);
        return view('admin.pages.edit',get_defined_vars());
    }
    public function update(Request $request, $id)
    {
        //update the record
        $Page = Page::find($id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            // print_r($imageType); die;
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                return redirect('admin/pages/edit/'.$id)->with('error','Image format must be jpeg,jpg,png');
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/page_image/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = $Page->image;
        }

            $Page->title = $request->get('title');
            $Page->slug = Str::slug($request->get('title'));
            $Page->arabic_title = $request->get('arabic_title');
            $Page->description = $request->get('description');
            $Page->arabic_description = $request->get('arabic_description');
            $Page->image = $imageData;
            $Page->save();

            // redirect
            return redirect("admin/pages/edit/$id")->with('success','Record has been created successfully!');

    }

    // update status
    public function update_status($id){
        $page = Page::where('id',$id)->first();
        if($page->status=='1'){
            Page::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            Page::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/pages')->with('success','Status has been updated successfully!');
    }

}
