<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Product;
use App\Models\ProductGallery;
use App\Models\ProductVariant;
use App\Models\VariantAttribute;
use App\Models\Attribute;
use App\Models\AttributeValue;
use App\Models\Category;
use App\Models\SubCategory;
use App\Models\Brand;
use App\Http\Requests\ProductFormRequest;
use DB;
use Form;
use Illuminate\Support\Str;

class ProductController extends Controller
{
    public function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:product_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:product_create', ['only' => ['create','store']]);
        $this->middleware('permission:product_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:product_delete', ['only' => ['destroy']]);
    }


    public function index()
    {
        $products = Product::orderBy('id','desc')->get();
        return view('admin.product.index',get_defined_vars());
    }

    public function create(Request $request)
    {
        $categories = Category::pluck('title', 'id')->toArray();
        $brands = Brand::pluck('title', 'id')->toArray();
        $attributes = Attribute::pluck('title', 'id')->toArray();
        $attribute_values = AttributeValue::pluck('title', 'id')->toArray();
        $step = !empty($request->get('step'))?$request->get('step'):1;
        $pid = !empty($request->get('pid'))?$request->get('pid'):'';
        if(!empty($pid)){
            $product = Product::find(base64_decode($pid));
            $gallery = ProductGallery::where('product_id',base64_decode($pid))->pluck('image','id')->toArray();
            if(empty($product)){
                $product = '';
            }
        }
        return view('admin.product.create',get_defined_vars());
    }

    public function store(ProductFormRequest $request)
    {
        $step = !empty($request->get('step'))?$request->get('step'):1;
        if($step == 1){
            $data = new Product;
            if(!empty($request->get('pid'))){
                $data = Product::find(base64_decode($request->get('pid')));
            }
            $data->title = $request->get('title');
            $data->slug = Str::slug($request->get('title'));
            $data->arabic_title = $request->get('arabic_title');
            $data->priority = $request->get('priority');
            $data->description = $request->get('description');
            $data->arabic_description = $request->get('arabic_description');
            $data->brand_id = $request->get('brand_id');
            $data->category_id = json_encode($request->get('category_id'));
            $data->sub_category_id = json_encode($request->get('sub_category_id'));
            if(!$data->save()){
                return redirect('admin/product/create')->with('error','Record not saved !!');
            }
            $pid = base64_encode($data->id);
            return redirect("admin/product/create?step=2&pid=$pid");
        }elseif($step == 2){
            if($files=$request->file('image')){
                DB::beginTransaction();
                try {
                    foreach($files as $file){
                        $imageTypeGet = $file->getClientmimeType();
                        $fileNameGet = $file->getClientOriginalName();
                        $fileNameUniqueGet = time() . '_' . $fileNameGet;
                        $destinationPathGet = public_path() . '/product_gallery/';
                        $file->move($destinationPathGet, $fileNameUniqueGet);
                        $imageDataGet = $fileNameUniqueGet;
                        $data = new ProductGallery;
                        $data->product_id =base64_decode($request->get('pid'));
                        $data->image = $imageDataGet;
                        $data->save();
                    }
                    DB::commit();
                }catch (\Exception $e) {
                    DB::rollback();
                    return redirect('admin/product/create')->with('error','Gallery Record not saved !!');
                }
                $pid = base64_encode($data->product_id);
                return redirect("admin/product/create?step=3&pid=$pid");
            }else{
                $pid = $request->get('pid');
                return redirect("admin/product/create?step=3&pid=$pid");
            }
        }elseif($step == 3){
            DB::beginTransaction();
            try {
                foreach ($request->get('stock') as $key => $value) {
                    $data = new ProductVariant();
                    $data->stock =$value;
                    $data->product_id =  base64_decode($request->get('pid'));
                    $data->barcode =$request->get('barcode')[$key];
                    $data->sku =$request->get('sku')[$key];
                    // $data->currency =$request->get('currency')[$key];
                    $data->currency ='KWD';
                    //    $data->variant_id =$request->get('variant_id')[$key];
                    $data->price =$request->get('price')[$key];
                    $data->special_price =$request->get('special_price')[$key];
                    if($data->save()){
                        $product = Product::find($data->product_id); // make product active when variant is added
                        if($product->status == 0){
                            $product->status = 1;
                            $product->save();
                        }

                        foreach ($request->get('attribute_id')[$key] as $k => $v) {
                            $dataV = new VariantAttribute();
                            $dataV->variant_id = $data->id;
                            $dataV->product_id =  base64_decode($request->get('pid'));
                            $dataV->attribute_id = $v;
                            $dataV->attribute_val_id = $request->get('attribute_value')[$key][$k];
                            $dataV->save();
                        }
                    }
                }
                DB::commit();
                return redirect('admin/product')->with('success','Data saved !!');
            }catch (\Exception $e) {
                DB::rollback();
                return redirect('admin/product/create')->with('error','Variant record not saved !!');
            }
        }
        return view('admin.product.create');

    }

    public function update(ProductFormRequest $request)
    {
        //update the record
        $step = !empty($request->get('step'))?$request->get('step'):1;
        $data = Product::find($request->product_id);
        $pid = $request->product_id;
        if($step == 1){
            $data->title = $request->get('title');
            $data->slug = Str::slug($request->get('title'));
            $data->arabic_title = $request->get('arabic_title');
            $data->priority = $request->get('priority');
            $data->description = $request->get('description');
            $data->arabic_description = $request->get('arabic_description');
            $data->brand_id = $request->get('brand_id');
            $data->category_id = json_encode($request->get('category_id'));
            $data->sub_category_id = json_encode($request->get('sub_category_id'));
            if(!$data->save()){
                return redirect("admin/product/edit/$pid?step=1")->with('error','Record not saved !!');
            }
            return redirect("admin/product/edit/$pid?step=2");
        }elseif($step == 2){
            if($files=$request->file('image')){
                try {
                    foreach($files as $file){
                        $imageTypeGet = $file->getClientmimeType();
                        $fileNameGet = $file->getClientOriginalName();
                        $fileNameUniqueGet = time() . '_' . $fileNameGet;
                        $destinationPathGet = public_path() . '/product_gallery/';
                        $file->move($destinationPathGet, $fileNameUniqueGet);
                        $imageDataGet = $fileNameUniqueGet;
                        $data = new ProductGallery;
                        $data->product_id =$pid;
                        $data->image = $imageDataGet;
                        $data->save();
                    }
                }catch (\Exception $e) {
                    return redirect("admin/product/edit/$pid?step=2")->with('error','Gallery Record not saved !!');
                }
                return redirect("admin/product/edit/$pid?step=3");
            }else{
                return redirect("admin/product/edit/$pid?step=3");
            }
        }elseif($step == 3){
            try {
                foreach ($request->get('stock') as $key => $value) {
                    $data = new ProductVariant();
                    $data->stock =$value;
                    $data->product_id =  $pid;
                    $data->barcode =$request->get('barcode')[$key];
                    $data->sku =$request->get('sku')[$key];
                    // $data->currency =$request->get('currency')[$key];
                    $data->currency ='KWD';
                    //    $data->variant_id =$request->get('variant_id')[$key];
                    $data->price =$request->get('price')[$key];
                    $data->special_price =$request->get('special_price')[$key];
                    if($data->save()){
                        $product = Product::find($data->product_id); // make product active when variant is added
                        if($product->status == 0){
                            $product->status = 1;
                            $product->save();
                        }
                        foreach ($request->get('attribute_id')[$key] as $k => $v) {
                            $dataV = new VariantAttribute();
                            $dataV->variant_id = $data->id;
                            $dataV->product_id =  $pid;
                            $dataV->attribute_id = $v;
                            $dataV->attribute_val_id = $request->get('attribute_value')[$key][$k];
                            $dataV->save();
                        }
                    }
                }
            }catch (\Exception $e) {
                // print_r($e->getMessage());die;
                return redirect("admin/product/edit/$pid?step=3");
            }
        }
        return redirect('admin/product')->with('success','Record has been updated successfully!');
    }

    public function edit(Product $product,Request $request)
    {
        $step = !empty($request->get('step'))?$request->get('step'):1;
        $attributes = Attribute::pluck('title', 'id')->toArray();
        // $attribute_values = AttributeValue::pluck('title', 'id')->toArray();
        $product_id = $product->id;
        // $product = $product;
        $selectedVariant=[];
        if(!empty($request->vid)){
            $selectedVariant = ProductVariant::where('id',$request->vid)->first();
        }

        $product = Product::with('gallery','productVariant')->where('id',$product_id)->first();
        $categories = Category::pluck('title', 'id')->toArray();
        $brands = Brand::pluck('title', 'id')->toArray();
        return view('admin.product.edit',get_defined_vars());
    }

    public function destroy(Request $request, Product $product)
    {
        $id = $product->id;
        $data = Product::find($id);
        $data->delete();
        // return redirect('admin/categories');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $product = Product::where('id',$id)->first();
        $status = $product->status == '0' ? '1':'0';
        Product::where('id',$id)->update([
            'status'=> $status
        ]);

        return redirect('admin/product')->with('success','Status has been updated successfully!');
    }

    public function get_ajax_attribute_value(Request $request){
        $attribute_id = $request->attribute_id;
        $attribute_value_name = $request->attribute_value_name;
        $attribute_values = AttributeValue::select('attribute_values.title', 'attribute_values.id')->where('attribute_values.attribute_id', '=', $attribute_id)->get()->toArray();
        $html = '<option value="">Select Value</option>';
        foreach($attribute_values as $attval){
            $html .= '<option value="'.$attval['id'].'">'.$attval['title'].'</option>';
        }
        echo $html;
    }

    public function update_variant(Request $request){
        // print_r($request->all());die;
        $vid = $request->get('vid');
        $pid = $request->get('pid');
        $data = ProductVariant::where('id',$vid)->where('product_id',$pid)->first();
        $data->stock =$request->get('stock')[0];
        $data->barcode =$request->get('barcode')[0];
        $data->sku =$request->get('sku')[0];
        // $data->variant_id =$request->get('variant_id')[0];
        // $data->currency =$request->get('currency')[0];
        $data->currency ='KWD';
        $data->price =$request->get('price')[0];
        $data->special_price =$request->get('special_price')[0];
        $attribute_id = @$request->get('attribute_id')[0];
        $attcnt = count($attribute_id);
        if($attcnt >0){
            VariantAttribute::where('product_id', $pid)->where('variant_id', $vid)->delete();
            for($i=0; $i<$attcnt; $i++) {
                $dataV = new VariantAttribute();
                $dataV->variant_id = $vid;
                $dataV->product_id = $pid;
                $dataV->attribute_id = $request->get('attribute_id')[0][$i];
                $dataV->attribute_val_id = $request->get('attribute_value')[0][$i];
                $dataV->save();
            }
        }

        if($data->save()){
            $arr = array('msg' => 'variant updated successfully', 'status' => true);
            return Response()->json($arr);
        }else{
            $arr = array('msg' => 'error', 'status' => false);
            return Response()->json($arr);
        }

    }
    // remove product image using ajax
    public function remove_ajax_product_image(Request $request){
        $image_id = $request->image_id;
        $product_id = $request->product_id;
        $delete_image = ProductGallery::where('id', $image_id)->where('product_id', $product_id)->delete();
        if($delete_image){
            $arr = array('msg' => 'image deleted successfully', 'status' => true);
            return Response()->json($arr);
        }else{
            $arr = array('msg' => 'error', 'status' => false);
            return Response()->json($arr);
        }
    }


    public function getSubcategory(Request $request){
        $cat_ids = !empty($request->cat_ids)?$request->cat_ids:[];
        $categories = SubCategory::whereIn('category_id', $cat_ids)->pluck('title','id')->toArray();
        if(!empty($categories)){
            $arr = array('data' => $categories, 'status' => true);
        }else{
            $arr = array('msg' => 'error', 'status' => false);
        }
        return Response()->json($arr);
    }
}
