<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Order;
use App\Models\Governorate;
use App\Models\Area;
use Form;

class ReportController extends Controller
{

    function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:report_view', ['only' => ['salesReport','areaWiseReport']]);
    }

    public function salesReport(Request $request){
        $status_filter = $request->status ?? '';
        $date_filter = $request->date ?? '';
        $payment_type = $request->payment_type ?? '';
        $start_date = $request->start_date ?? '';
        $end_date = $request->end_date ?? '';

        if($date_filter == 'today'){
            $start_date = date('Y-m-d');
            $end_date = date('Y-m-d');
        }
        if($date_filter == 'yesterday'){
            $start_date = date('Y-m-d', strtotime('-1 day'));
            $end_date = date('Y-m-d', strtotime('-1 day'));
        }
        if($date_filter == 'this_week'){
            $curent_date = date('Y-m-d');
            $ts = strtotime($curent_date);
            $start = (date('w', $ts) == 0) ? $ts : strtotime('last sunday', $ts);
            $start_date = date('Y-m-d', $start);
            $end_date = date('Y-m-d', strtotime('next saturday', $start));
        }
        if($date_filter == 'this_month'){
            $start_date = date('Y-m-01');
            $end_date = date('Y-m-t');
        }
        if($date_filter == 'last_month'){
            $start_date = date('Y-m-01',strtotime('-1 months'));
            $end_date = date('Y-m-t',strtotime('-1 months'));
        }
        if($date_filter == 'custom'){
            $start_date = $_REQUEST['start_date'];
            $end_date = $_REQUEST['end_date'];
        }
        $status = [
            'New' => 'New',
            'Order Process' => 'Order Process',
            'Order Shipped' => 'Order Shipped',
            'Out For Delivery' => 'Out For Delivery',
            'Delivered' => 'Delivered',
            'Cancelled' => 'Cancelled'
        ];
        $paymentType = [
            'KNET' => 'Knet',
            'COD' => 'Cash On Delivery'
        ];
        $dateSelction = [
            'today' => 'Today',
            'yesterday' => 'Yesterday',
            'this_week' => 'This Week',
            'this_month' => 'This Month',
            'last_month' => 'Last Month',
            'custom' => 'Custom'
        ];

        $orders = [];
        $datesArr = [];
        if(!empty($request->all())){
            $orderQuery = Order::with('userAddress')->orderBy('id', 'desc');
            if(!empty($status_filter)){
                $orderQuery->where('order_status', $status_filter);
            }
            if(!empty($payment_type)){
                if($payment_type == 'COD'){
                    $orderQuery->where('payment_type', $payment_type);
                }else{
                    $orderQuery->where('payment_type', '!=', 'COD');
                }

            }
            if(!empty($start_date) && !empty($end_date)){
                $orderQuery->WhereDate('created_at', '>=', $start_date);
                $orderQuery->WhereDate('created_at', '<=', $end_date);
            }
            $orders = $orderQuery->get();

        }else{
            $orderQuery = Order::with('userAddress')->orderBy('id', 'desc');
            $orders = $orderQuery->get();
        }
        return view('admin.reports.sales', [
            'status' => $status,
            'paymentType' => $paymentType,
            'dateSelction' => $dateSelction,
            'status_filter' => $status_filter,
            'date' => $date_filter,
            'payment_type' => $payment_type,
            'start_date' => $start_date,
            'end_date' => $end_date,
            'orders' => $orders
        ]);
    }

    public function areaWiseReport(Request $request){
        $governorate_id = $request->governorate ?? '';
        $area_id = $request->area ?? '';
        $start_date = $request->start_date ?? '';
        $end_date = $request->end_date ?? '';
        $date_filter = $request->date ?? '';
        $governorates = Governorate::pluck('title', 'id')->toArray();

        $orders = [];
        $datesArr = [];
        if(!empty($request->all())){

            $orderQuery = Order::whereHas('userAddress', function($q)  use ($governorate_id,$area_id)
                {
                    if($governorate_id != ''){
                        $q->where('governorate', '=', $governorate_id);
                    }

                    if($area_id != ''){
                        $q->orWhere('area', '=', $area_id);
                    }


                });
                if(!empty($start_date) && !empty($end_date)){
                    $orderQuery->WhereDate('created_at', '>=', $start_date);
                    $orderQuery->WhereDate('created_at', '<=', $end_date);
                }
                $orders = $orderQuery->orderBy('id', 'desc')->get();
        }else{
            $orderQuery = Order::with('userAddress')->orderBy('id', 'desc');
            $orders = $orderQuery->get();
        }
        return view('admin.reports.area_wise_report', [
            'governorates' => $governorates,
            'governorate_id' => $governorate_id,
            'area_id' => $area_id,
            'date' => $date_filter,
            'start_date' => $start_date,
            'end_date' => $end_date,
            'orders' => $orders
        ]);
    }

    public function filterDefaultAreas(Request $request)
    {
        $governorate_id = $request->input('governorate_id');
        $area_id = $request->input('area_id');
        $areas = Area::select('areas.title', 'areas.id')->where('areas.governorate_id', '=', $governorate_id)->pluck('areas.title', 'areas.id')->toArray();
        $dd = Form::select('area', $areas,$area_id, ['id'=>'area','class' => 'form-control','placeholder' => 'Select Area']);
        echo $dd;
    }
}
