<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Spatie\Permission\Models\Role;

class RoleController extends Controller
{
    public function __construct()
    {
        $this->middleware('adminauth');
        $this->middleware('permission:role_view', ['only' => ['index']]);
        $this->middleware('permission:role_create', ['only' => ['create','store']]);
        $this->middleware('permission:role_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:role_delete', ['only' => ['destroy']]);
    }

    /**
     * Display the List view.
     *
     */
    public function index()
    {
        $roles = Role::all();
        return view('admin.role.index', ['roles' => $roles]);
    }


    /**
     * get listing with ajax
     * @return Renderable
     */
    public function ajaxList(Request $request)
    {
        $draw = $request->get('draw');
        $start = $request->get("start");
        $rowperpage = $request->get("length"); // total number of rows per page

        $columnIndex_arr = $request->get('order');
        $columnName_arr = $request->get('columns');
        $order_arr = $request->get('order');
        $search_arr = $request->get('search');

        $columnIndex = $columnIndex_arr[0]['column']; // Column index
        $columnName = $columnName_arr[$columnIndex]['data']; // Column name
        $columnSortOrder = $order_arr[0]['dir']; // asc or desc
        $searchValue = $search_arr['value']; // Search value

        $totalRecords = Role::select('count(*) as allcount')->count();
        $totalRecordswithFilter = Role::select('count(*) as allcount')->where('name', 'like', '%' . $searchValue . '%')->count();

        // Get records, also we have included search filter as well
        $records = Role::orderBy('id', 'desc')
             ->orderBy($columnName, $columnSortOrder)
            ->where('roles.name', 'like', '%' . $searchValue . '%')
            ->select('roles.*')
            ->skip($start)
            ->take($rowperpage)
            ->get();

        $data_arr = array();

        foreach ($records as $record) {

            $actionHtml = '<li><a class="dropdown-item" href="'.route('role.edit', $record->id).'">Edit</a></li>'; //todo

            $data_arr[] = array(
                "id" => $record->id,
                "role" => $record->name,
                'action' => ''
            );
        }

        $response = array(
            "draw" => intval($draw),
            "iTotalRecords" => $totalRecords,
            "iTotalDisplayRecords" => $totalRecordswithFilter,
            "aaData" => $data_arr,
        );

        echo json_encode($response);
    }

    /**
     * Display the Role Creation view.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('admin.role.create');
    }

    /**
     * Handle an incoming role request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(Request $request)
    {

        $request->validate([
            'name' => ['required', 'string', 'max:255'],
        ]);

        $role = Role::create([
            'name' => $request->name,
        ]);

        if($role){
            return redirect('admin/permission/index')->with('message', 'Role created successfully!');
        } else {
            return back()->withError('Something went wrong! Please try again.');
        }
    }

    /**
     * Edit the role.
     *
     */
    public function edit(Role $role)
    {
        return view('admin.role.edit', ['role' => $role]);
    }

    /**
     * update the role.
     *
     */
    public function update(Request $request, $id)
    {
        $role = Role::findOrFail($id);
        $role->update($request->all());
        if($role){
            return redirect('admin/permission/index')->with('message', 'Role created successfully!');
        } else {
            return back()->withError('Something went wrong! Please try again.');
        }
    }

    /**
     * delete the role.
     *
     */
    public function destroy(Request $request, $id)
    {
        $role = Role::findOrFail( $request->id );
        if($role->delete()){
            return back()->with('message','Role deleted successfully');
        } else {
            return back()->withError('Something went wrong! Please try again.');
        }
    }
}
