<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Settings;

class SettingsController extends Controller
{
    public function __construct()
    {
        $this->middleware('adminauth');
        // $this->middleware('permission:role_view', ['only' => ['index']]);
    }

    //
      /**
     * Display a listing of the resource.
     * @return Renderable
     */
    public function index()
    {
        return view('admin.settings.index');
    }


    /**
     * get listing with ajax
     * @return Renderable
     */
    public function ajaxList(Request $request)
    {
        $draw = $request->get('draw');
        $start = $request->get("start");
        $rowperpage = $request->get("length"); // total number of rows per page

        $columnIndex_arr = $request->get('order');
        $columnName_arr = $request->get('columns');
        $order_arr = $request->get('order');
        $search_arr = $request->get('search');

        $columnIndex = $columnIndex_arr[0]['column']; // Column index
        $columnName = $columnName_arr[$columnIndex]['data']; // Column name
        $columnSortOrder = $order_arr[0]['dir']; // asc or desc
        $searchValue = $search_arr['value']; // Search value

        $totalRecords = Settings::select('count(*) as allcount')->count();
        $totalRecordswithFilter = Settings::select('count(*) as allcount')->count();

        // Get records, also we have included search filter as well
        // $all = Settings::where('type', '!=', 'logo')->get();
        $records = Settings::orderBy($columnName, $columnSortOrder)
        // ->where('title', 'like', '%' . $searchValue . '%')
        ->skip($start)
        ->take($rowperpage)
        ->get();

        $data_arr = array();

        foreach ($records as $record) {
            $data_arr[] = array(
                "id" => $record->id,
                // 'logo'=> '<img class="logo-thumb" src="'. asset('/storage').'/'.$record->logo.'">',
                "facebook_link" => $record->facebook_link,
                "twitter_link" => $record->twitter_link,
                "linkedin_link" => $record->linkedin_link,
                "pinterest_link" => $record->pinterest_link,
                "low_inventory_alert_value" => $record->low_inventory_alert_value,
                "insta_link" => $record->insta_link,
                "default_shipping_cost" => $record->default_shipping_cost,
                'action' => ''
            );
        }

        $response = array(
            "draw" => intval($draw),
            "iTotalRecords" => $totalRecords,
            "iTotalDisplayRecords" => $totalRecordswithFilter,
            "aaData" => $data_arr,
        );

        echo json_encode($response);
    }

    /**
     * Show the form for creating a new resource.
     * @return Renderable
     */
    public function create()
    {
        $settings = Settings::first();

        if($settings){
            return view('admin.settings.edit', ['settings' => $settings]);
        } else {
            return view('admin.settings.create');
        }

    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Renderable
     */
    public function store(Request $request)
    {
        // $logo_path = '';
        // if($request->file('logo')){
        //     $logo_path = $request->file('logo')->store('site-logo');
        // }
        $request->validate([
            'facebook_link' => 'required',
            'insta_link' => 'required',
            'low_inventory_alert_value'=>['required','integer'],
            'default_shipping_cost'=>['required','integer'],
            'tax_prcnt'=>['required','integer']
        ]);

        $setting = Settings::create([
            // 'logo' => $logo_path,
            'admin_email' => $request->admin_email,
            'facebook_link' =>  $request->facebook_link,
            'insta_link' =>  $request->insta_link,
            'low_inventory_alert_value' => $request->low_inventory_alert_value,
            'default_shipping_cost' => $request->default_shipping_cost,
            'tax_prcnt' => $request->tax_prcnt,
        ]);

        if($setting){
            return redirect('admin/settings/index')->with('message','Settings saved successfully');
        } else {
            return back()->withError('Something went wrong! Please try again.');
        }
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function show($id)
    {
        return view('admin.settings.show');
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Renderable
     */
    public function edit($id)
    {
        $settings = Settings::find($id);
        if(!$settings){
            return redirect()->back();
        }
        return view('admin.settings.edit', ['settings' => $settings]);
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Renderable
     */
    public function update(Request $request, $id)
    {
        $settings = Settings::find($id);
        $request->validate([
            'facebook_link' => 'required',
            'insta_link' => 'required',
            'low_inventory_alert_value'=>['required','integer'],
            'default_shipping_cost'=>['required','integer'],
            'tax_prcnt'=>['required','integer']
        ]);
        $input = $request->all();
        if($settings->fill($input)->save()){
            return redirect('admin/settings/index')->with('message','Settings saved successfully');
        } else {
            return back()->withError('Something went wrong! Please try again.');
        }
    }
}
