<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\SubCategory;
use App\Http\Requests\SubCategoryFormRequest;
use Validator;
use Session;
use Auth;
use Illuminate\Support\Str;

class SubCategoryController extends Controller
{
     /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()

    {
        $this->middleware('adminauth');
        $this->middleware('permission:sub_category_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:sub_category_create', ['only' => ['create','store']]);
        $this->middleware('permission:sub_category_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:sub_category_delete', ['only' => ['destroy']]);
    }
    public function index()
    {
        $subcategories = SubCategory::with('categories')->orderBy('id','desc')->get();
        return view('admin.sub_categories.index',get_defined_vars());
    }

    public function create()
    {
        $categories = Category::where('categories.status',1)->pluck('categories.title', 'categories.id','categories.arabic_title')->toArray();
        return view('admin.sub_categories.create',get_defined_vars());
    }

    public function store(SubCategoryFormRequest $request)
    {
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                return redirect('admin/sub_categories/create')->with('error','Image format must be jpeg,jpg,png');
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/categories_images/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = '';
        }
        $data = new SubCategory;
        $data->category_id = $request->get('category_id');
        $data->title = $request->get('title');
        $data->arabic_title = $request->get('arabic_title');
        $data->slug = Str::slug($request->get('title'));
        $data->description = $request->get('description');
        $data->arabic_description = $request->get('arabic_description');
        $data->image = $imageData;
        $data->status = $request->get('status');
        $data->save();

        // redirect
        // Session::flash('message', 'Record has been created successfully!');
        return redirect('admin/sub_categories')->with('success','Record has been created successfully!');
    }

    public function edit(SubCategory $subCategory)
    {
        $category = $subCategory;
        $categories = Category::where('categories.status',1)->pluck('categories.title', 'categories.id','categories.arabic_title')->toArray();
        return view('admin.sub_categories.edit',get_defined_vars());
    }

    public function update(SubCategoryFormRequest $request,$subcategory_id)
    {
        //update the record
        // $category_update = $category;
        $subcategory = SubCategory::find($subcategory_id);
        if ($file = $request->hasFile('image')) {
            $file = $request->file('image');
            $imageType = $file->getClientmimeType();
            // print_r($imageType); die;
            $rules = array(
                'image' => 'mimes:jpeg,jpg,png',
            );

            $validator = Validator::make($request->all(), $rules);

            if ($validator->fails()) {
                return redirect('admin/sub_categories/edit/'.$subcategory_id)->with('error','Image format must be jpeg,jpg,png');
            } else {
                $fileName = $file->getClientOriginalName();
                $fileNameUnique = time() . '_' . $fileName;
                $destinationPath = public_path() . '/categories_images/';
                $file->move($destinationPath, $fileNameUnique);
            }
            $imageData = $fileNameUnique;
        } else {
            $imageData = $subcategory->image;
        }

            $subcategory->title = $request->get('title');
            $subcategory->arabic_title = $request->get('arabic_title');
            $subcategory->slug = Str::slug($request->get('title'));
            $subcategory->description = $request->get('description');
            $subcategory->arabic_description = $request->get('arabic_description');
            $subcategory->image = $imageData;
            $subcategory->status = $request->get('status');
            $subcategory->save();

            // redirect
            // Session::flash('message', 'Record has been created successfully!');
            return redirect('admin/sub_categories')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, SubCategory $subCategory)
    {
        $id = $subCategory->id;
        $data = SubCategory::find($id);
        $data->delete();
        Session::flash('message', 'Record has been deleted successfully!');
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    // update status
    public function update_status($id){
        $subCategory = SubCategory::where('id',$id)->first();
        if($subCategory->status=='1'){
            SubCategory::where('id',$id)->update([
                'status'=>'0'
            ]);
        }else{
            SubCategory::where('id',$id)->update([
                'status'=>'1'
            ]);
        }

        return redirect('admin/sub_categories')->with('success','Status has been updated successfully!');
    }
}
