<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\UserAddress;
use App\Http\Requests\UserFormRequest;
use Illuminate\Support\Facades\Auth;

class UserController extends Controller
{
    public function __construct()

    {
        $this->middleware('adminauth');
        $this->middleware('permission:users_view', ['only' => ['index','update_status']]);
        $this->middleware('permission:users_create', ['only' => ['create','store']]);
        $this->middleware('permission:users_edit', ['only' => ['edit','update']]);
        $this->middleware('permission:users_delete', ['only' => ['destroy']]);
    }


    public function index()
    {
        $users = User::orderBy('id','desc')->get();
        return view('admin.users.index',get_defined_vars());
    }

    public function create()
    {
        return view('admin.users.create',get_defined_vars());
    }

    public function store(UserFormRequest $request)
    {
        $data = new User;
        $data->name = $request->get('name');
        $data->email = $request->get('email');
        $data->phone_number = $request->get('phone_number');
        $data->password = bcrypt($request->get('password'));
        $data->role = User::USER;
        $data->status = $request->get('status');
        if(!$data->save()){
            $data->assignRole($data->role);
            return redirect('admin/user/create')->with('error','Record not saved !!');
        }
        return redirect('admin/users')->with('success','Record has been created successfully!');
    }

    public function edit(User $user)
    {
        $user = $user;
        return view('admin.users.edit',get_defined_vars());
    }

    public function update(UserFormRequest $request)
    {
        //update the record
        $data = User::find($request->user_id);

        $data->name = $request->get('name');
        $data->phone_number = $request->get('phone_number');
        $data->password = bcrypt($request->get('password'));
        $data->status = $request->get('status');
        if(!$data->save()){
            return redirect('admin/user/create')->with('error','Record not saved !!');
        }
        return redirect('admin/users')->with('success','Record has been updated successfully!');
    }


    public function destroy(Request $request, User $user)
    {
        $id = $user->id;
        $data = User::find($id);
        $data->delete();
        $response = array('status'=> true, 'msg' => 'Record has been deleted successfully!');
        return $response;
    }

    //update status
    public function update_status($id){
        $user = User::where('id',$id)->first();
        $status = $user->status == '0' ? '1':'0';
        User::where('id',$id)->update([
            'status'=> $status
        ]);

        return redirect('admin/users')->with('success','Status has been updated successfully!');
    }

     //Get user addresses
     public function user_addresses($id)
     {
         //
         $data = UserAddress::where('user_id',$id)->get();
         $user = User::find($id);
         return view('admin.users.user_addresses',get_defined_vars());
     }
}
