<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Providers\RouteServiceProvider;
use App\Models\User;
use Illuminate\Foundation\Auth\RegistersUsers;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\Models\User
     */
    protected function create(array $data)
    {
        return User::create([
            'name' => $data['name'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
        ]);
    }

    public function registerCheckout(Request $request)
    {
        $request->validate([
            'cemail' => 'required|email:rfc,dns|unique:users,email',
            'name' => 'required|unique:users,name',
            'phone_number'=>'required',
            'cpassword' => 'required|min:8',
            'password_confirmation' => 'required|same:cpassword'
        ]);
        $user = new User;
        $user->name = $request->name;
        $user->email = $request->cemail;
        $user->phone_number = $request->phone_number;
        $user->password = Hash::make($request->cpassword);
        $user->role = User::USER;

        $data =['email' => $request->cemail,  'password' => $request->cpassword];

        if($user->save()?auth()->attempt($data):auth()->guard('admin')->attempt($data)){
            transferCartItem(); // Transfer guest cart item to user cart
            return back()->with('success','Your account created successfully!');
        }
        return back()->with('error','Something bad happened !');
    }
}
