<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Repositories\CartRepository;
use App\Models\Cart;

class CartController extends Controller
{
    public function __construct()
    {

    }

    //view Cart
    public function cart(Request $request)
    {
        $cart = getCartProducts();
        $locale = \Lang::getLocale();
        $title = ($locale == 'ar')?'arabic_title':'title';

        return view('frontend.cart')->with(['cart'=>$cart,'title'=>$title]);
    }

    // Add Product to Cart Table
    public function addToCart(Request $request)
    {
        try{
            $arr = [
                'status' => 'success',
                'message' => "Product Added To Cart !!"
            ];
            if(checkLogin()){
                $cart = Cart::where([
                    'user_id' => authUser()->user()->id,
                    'product_id' => $request->pid,
                    'variant_id'=> $request->vid
                ])->first();
                if($cart){
                    $cart->quantity+=$request->quantity;
                }else{
                    $cart = new Cart();
                    $cart->user_id = authUser()->user()->id;
                    $cart->user_ip = \Request::ip();
                    $cart->product_id = $request->pid;
                    $cart->variant_id = $request->vid;
                    $cart->quantity = $request->quantity;
                }
                if($request->attr){
                    $cart->attribute_id = $request->attr;
                    $cart->attribute_val_id = json_encode([$request->color,$request->size]);
                }
                $cart->save();
            }else{
                $cart = Cart::where([
                    'user_id' => 0,
                    'user_ip' => \Request::ip(),
                    'product_id' => $request->pid,
                    'variant_id'=> $request->vid
                ])->first();
                if($cart){
                    $cart->quantity+=$request->quantity;
                }else{
                    $cart = new Cart();
                    $cart->user_id = 0;
                    $cart->user_ip = \Request::ip();
                    $cart->product_id = $request->pid;
                    $cart->variant_id = $request->vid;
                    $cart->quantity = $request->quantity;
                }
                if($request->attr){
                    $cart->attribute_id = $request->attr;
                    $cart->attribute_val_id = json_encode([$request->color,$request->size]);
                }
                $cart->save();
            }
        }catch(Exception $e){
            $arr = [
                'status' => 'danger',
                'message' => "Something went wrong! Please try again."
            ];
        }
        return Response()->json($arr);
    }

     /**
    * Remove product from Cart
    */
    public function removeCart(Request $request)
    {
        try{
            $cart = Cart::where([
                'id' => $request->pid,
            ])->first();

            if(!empty($cart) && $cart->delete()){
                $arr = [
                    'status' => 'success',
                    'message' => "Product removed from Cart !!."
                ];
            }else{
                $arr = [
                    'status' => 'danger',
                    'message' => "Something went wrong! Please try again."
                ];
            }
        }catch(Exception $e){
            $arr = [
                'status' => 'danger',
                'message' => "Something went wrong! Please try again."
            ];
        }
        return Response()->json($arr);
    }

     /**
    * Manipulate cart product quantity
    */
    public function productQuantity(Request $request)
    {
        $cart = Cart::where('id',$request->id)->first();
        $cart->quantity +=$request->plusMinus;
        $grandTotal = grandTotal($request->subTotal);
        if($cart->save()){
            $arr = [
                'status' => 'success',
                'quantity' => $cart->quantity,
                'grandTotal'=> $grandTotal
            ];
        }else{
            $arr = [
                'status' => 'danger',
                'message' => "Something went wrong! Please try again."
            ];
        }
        return Response()->json($arr);
    }

      /**
    * Get grand total on the basis of shipping cost
    */
    public function getTotal(Request $request)
    {
        $grandTotal = grandTotal($request->subTotal,$request->shiping);
        $arr = [
            'status' => 'success',
            'grandTotal'=> $grandTotal
        ];
        return Response()->json($arr);
    }
}
