<?php

namespace App\Http\Controllers;
use App\Models\HomeContent;
use App\Models\Product;
use App\Models\NewsLetterSubscriber;
use App\Models\User;
use App\Models\Page;
use App\Models\Banner;
use App\Models\Category;
use App\Models\Job;
use App\Models\Career;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Auth;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Facades\Validator;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        // $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $newArrival=$banners=$mid_slider=[];
        $product1=$product2=$product3=$sales_banner1=$sales_banner2=$sales_banner3=$signup='';
        $content = HomeContent::first();
        $locale = \Lang::getLocale();
        if($locale == 'ar'){
            $title = 'arabic_title';
            $desc = 'arabic_description';
        }else{
            $title = 'title';
            $desc = 'description';
        }

        if($content->banner_type == 0){
            if(!empty($content->slider_banner_id)){
                $banners = $this->getBanner(json_decode($content->slider_banner_id,true));
            }
        }else{
            if(!empty($content->slider_banner_id2)){
                $banners = $this->getBanner(json_decode($content->slider_banner_id2,true));
            }
        }

        //
        if(!empty($content->product1)){
            $product1 = $this->getBanner($content->product1,false);
        }
        if(!empty($content->product2)){
            $product2 = $this->getBanner($content->product2,false);
        }
        if(!empty($content->product3)){
            $product3 = $this->getBanner($content->product3,false);
        }
        //sales
        if(!empty($content->sales_banner1)){
            $sales_banner1 = $this->getBanner($content->sales_banner1,false);
        }
        if(!empty($content->sales_banner2)){
            $sales_banner2 = $this->getBanner($content->sales_banner2,false);
        }
        if(!empty($content->sales_banner3)){
            $sales_banner3 = $this->getBanner($content->sales_banner3,false);
        }
        //signup
        if(!empty($content->signup)){
            $signup = $this->getBanner($content->signup,false);
        }
        //mid_slider
        if(!empty($content->signup)){
            $mid_slider = $this->getBanner(json_decode($content->mid_slider,true));
        }

        $categories = Category::where('status',1)->select('title as key',"$title as title",'id')->take(3)->get();
        $product = Product::select('id',"$title as title")->where('status',1)->where('created_at', '>=', Carbon::now()->subMonth(2))->take(10);
        $newArrival['all']= $product->get();
        //category wise new products
        foreach ($categories as  $value) {
            $query = clone $product;
            $newArrival[$value->key] = $query->where('category_id','like','%"'.$value->id.'"%')->get();
        }

        $mustHave = Product::select('id',"$title as title")->where('status',1)->leftJoin('wishlists as w', function($join) {
            $join->on('products.id', '=', 'w.product_id');
        })->select('products.id',"$title as title",\DB::raw('COUNT(products.id) as pr_count,COUNT(w.product_id) as p_count'))
        ->groupBy('products.id')->groupBy('w.product_id')
        ->orderBy('p_count', 'DESC')->take(8)->get();

        return view('frontend.home.index', get_defined_vars());
    }

    public function getBanner($ids,$all=true)
    {
        $locale = \Lang::getLocale();
        if($locale == 'ar'){
            $title = 'arabic_title';
            $desc = 'arabic_description';
        }else{
            $title = 'title';
            $desc = 'description';
        }
        $query = Banner::where('status',1)->whereIn('id', is_array($ids)?$ids:[$ids])->select('title as key',"$title as title","$desc as description",'banner_url','image');

        return $all?$query->get():$query->first();
    }

    /**
    * Detail page of  aboutUs
    */
    public function aboutUs(Request $request)
    {
        $locale = \Lang::getLocale();
        if($locale == 'ar'){
            $title = 'arabic_title';
            $desc = 'arabic_description';
        }else{
            $title = 'title';
            $desc = 'description';
        }

        $data = Page::where('slug',$request->slug)->select("$title as title","$desc as description",'image')->first();
        if(!$data){
            return back();
        }
        return view('frontend.home.aboutUs', ['data'=>$data]);
    }

    /**
    * Subcribe to NewsLetterSubscriber
    */
    public function subscriberFrontsAjax(Request $request)
    {
        try{
            $response['success'] = false;
            if(empty($request->email)){
                $response['msg'] = 'Please Enter Email !!';
                return response()->json($response);
            }

            $exists = NewsLetterSubscriber::where('email', $request->email)->first();
            if($exists){
                $response['msg'] = 'You are already subscribed for NewsLetter !!';
                return response()->json($response);
            }

            $subscriber = NewsLetterSubscriber::create([
                'user_id' => authUser()->user() ? authUser()->user()->id : null,
                'email' => $request->email,
                'ip_address' => \Request::ip()
            ]);

            $response['success'] = true;
            $response['msg'] = 'Subscribed Successfully !!';

        } catch(\Exception $e){
            $response['msg'] = 'Something went wrong !';
        }
        return response()->json($response);
    }

    //
    public function contactUs(Request $request){

        if($request->has('contact_submit')){
            $info = array(
                'first_name' => $request->input('first_name'),
                'last_name' => $request->input('last_name'),
                'mobile' => $request->input('mobile'),
                'email' => $request->input('email'),
                'comment' => $request->input('comment'),
            );
            // Mail::send('emails.contact_us', $info, function ($message)
            // {
            //     $message->to($this->admin_email, 'Spa Time')->subject('Contact request');
            //     //->from($this->mail_from, $this->appname);
            // });
            return redirect()->back()->with('success', 'Submitted Successfully!!');
        }
        return view('frontend.contact-us',get_defined_vars());
    }

     //
    public function careers(Request $request){

        $locale = \Lang::getLocale();
        $title = ($locale == 'ar')?'arabic_title':'title';
        if($request->has('career_submit')){
            if ($file = $request->hasFile('cvfile')) {
                $file = $request->file('cvfile');
                $imageType = $file->getClientmimeType();
                $rules = array(
                    'cvfile' => 'required|file|mimes:pdf',
                );

                $validator = Validator::make($request->all(), $rules);

                if ($validator->fails()) {
                    return redirect()->back()->with('message', 'File format must be Pdf !!');
                } else {
                    $fileName = $file->getClientOriginalName();
                    $fileNameUnique = time() . '_' . $fileName;
                    $destinationPath = public_path() . '/careers_file/';
                    $file->move($destinationPath, $fileNameUnique);
                }
                $file = $fileNameUnique;
            } else {
                $file = '';
            }

            $career = new Career();
            $career->first_name = $request->input('first_name');
            $career->last_name = $request->input('last_name');
            $career->email = $request->input('email');
            $career->job_id = $request->input('job_id');
            $career->mobile = $request->input('mobile');
            $career->dob = $request->input('dob');
            $career->file = $file;
            $career->additional_info = $request->input('additional_info');
            if(!$career->save()){
                return redirect()->back()->with('message', 'Something wrong happend !!');
            }
            return redirect()->back()->with('message', 'Submitted Successfully!!');


            // Mail::send('emails.contact_us', $info, function ($message)
            // {
            //     $message->to($this->admin_email, 'Spa Time')->subject('Contact request');
            //     //->from($this->mail_from, $this->appname);
            // });

        }
        $jobs = Job::where('status',1)->get();
        return view('frontend.career',get_defined_vars());
    }

    public function download($filename)
    {
        $filePath = public_path() . '/careers_file/'. $filename;

        // if (!Storage::exists($filename)) {
        //     abort(404);
        // }

        return response()->download($filePath);
    }

    public function search(Request $request)
    {
        $locale = \Lang::getLocale();
        if($locale == 'ar'){
            $title = 'arabic_title';
            $desc = 'arabic_description';
        }else{
            $title = 'title';
            $desc = 'description';
        }
        if(isset($request->json)){
            $product = Product::select('id',"$title as title")->where('status',1)->where('title','like','%'.$request->search.'%')->orWhere('arabic_title','like','%'.$request->search.'%')->take(10)->get();
            return response()->json(['products'=>$product]);

        }else{
            $product = Product::select('id',"$title as title","$desc as description")->where('status',1)->where('title','like','%'.$request->search.'%')->orWhere('arabic_title','like','%'.$request->search.'%')->paginate(8);
            return view('frontend.search_list',get_defined_vars());
        }
    }
}
