<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Auth;
use App\Models\User;
use App\Models\Order;
use App\Models\UserAddress;
use Illuminate\Support\Facades\Hash;
use App\Rules\MatchOldPassword;

class ProfileController extends Controller
{
    //
    public function __construct()
    {
        $this->middleware('checkLogin');
    }

    public function myProfile(Request $request)
    {
        $auth = is_admin()?auth()->guard('admin'):auth();
        $user = $auth->user();

        return view('frontend.profile.index', ['user'=>$user]);
    }

    public function profileUpdte(Request $request){
        $user = User::find($request->id);
        $request->validate([
            'name' => 'required',
            'email' => 'required',
            'phone_number'=>['required'],
        ]);

        $user->name = $request->get('name');
        $user->phone_number = $request->get('phone_number');
        $user->email = $request->get('email');
        if(!$user->save()){
            return redirect('/my-profile')->with('error','Record not saved !!');
        }
        return redirect('/my-profile')->with('success','Record has been updated successfully!');
    }

    public function myOrders()
    {
        $locale = \Lang::getLocale();
        $title = ($locale == 'ar')?'arabic_title':'title';
        $orders = Order::where('user_id',authUser()->user()->id)->get();
        return view('frontend.profile.order', get_defined_vars());
    }

    public function myAddress(Request $request)
    {
        $userAddresss = UserAddress::where([
            'status' => '1',
            'user_id' => authUser()->user()->id
        ])->get();

        return view('frontend.profile.address', ['userAddresss'=>$userAddresss]);
    }

    public function updateAddress(Request $request)
    {
        $input = $request->all();
        unset($input['_token']);
        foreach($input as $field){
            if($field == ''){
                return response()->json(['status'=>'danger','msg'=>'Please fill all the fields']);
            }
        }

        $userAddress = UserAddress::where('id',$request->id)->where('user_id',$request->input('user_id'))->first();
        $userAddress->fill($input)->save();

        return response()->json(['status'=>'success','msg'=>'Address updated successfully !!']);
    }

    public function addAddress(Request $request)
    {
        $input = $request->all();
        unset($input['_token']);
        foreach($input as $field){
            if($field == ''){
                return response()->json(['status'=>'danger','msg'=>'Please fill all the fields']);
            }
        }

        $userAddress = new UserAddress();
        $userAddress->user_id=authUser()->user()->id;
        $userAddress->first_name = $input['first_name'];
        $userAddress->last_name = $input['last_name'];
        $userAddress->address_type = $input['address_type'];
        $userAddress->governorate = $input['governorate'];
        $userAddress->area = $input['area'];
        $userAddress->contact_no = $input['contact_no'];
        $userAddress->appartment = $input['appartment'];
        $userAddress->address = $input['address'];
        $userAddress->pincode = $input['pincode'];
        $userAddress->landmark = $input['landmark'];
        $userAddress->house_no = $input['house_no'];

        if($userAddress->save()){
            return response()->json(['status'=>'success','msg'=>'Address updated successfully !!']);
        }
        return response()->json(['status'=>'danger','msg'=>'Something bad happened !!']);
    }


    public function changePasswordView(Request $request)
    {
        return view('frontend.profile.change-password');
    }

    public function changePassword(Request $request){

            $request->validate([
                'password' => ['required', new MatchOldPassword],
                'new_password' => 'required',
                'confirm_password' => 'same:new_password',
            ]);

            if($request->new_password != $request->confirm_password){
                return redirect('/change')->with('error','New Password does not match !!');
            }

            $auth = is_admin()?auth()->guard('admin'):auth();
            User::find($auth->user()->id)->update(['password'=> Hash::make($request->new_password)]);

            return redirect('change')->with('success','Password changed successfully!');
    }

}
