<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Wishlist;

class WishlistController extends Controller
{

    public function __construct()
    {
        $this->middleware('checkLogin');
    }

    /**
    *  View user wishlist page
    */
    public function wishlist(Request $request)
    {
        $wishlist = Wishlist::select('product_id','user_id','variant_id')->where([
            'user_id' => authUser()->user()->id,
        ])->get();

        $locale = \Lang::getLocale();
        $title = ($locale == 'ar')?'arabic_title':'title';

        return view('frontend.wishlist')->with(['wishlist'=>$wishlist,'title'=>$title]);
    }

    /**
    *  Add product to wishlist
    */
    public function addWishlist(Request $request){
        try{
            $exist = Wishlist::where([
                'user_id' => authUser()->user()->id,
                'product_id' => $request->id,
                'variant_id'=> $request->vid
            ])->first();
            if(!$exist){
                $wishlist =  new Wishlist;
                $wishlist->user_id = authUser()->user()->id;
                $wishlist->product_id = $request->id;
                $wishlist->variant_id = $request->vid;

                if($wishlist->save()){
                    $arr = [
                        'status' => 'success',
                        'message' => "Product added to wishlist successfully."
                    ];
                } else {
                    $arr = [
                        'status' => 'danger',
                        'message' => "Something went wrong! Please try again."
                    ];
                }

            } else {
                $arr =[
                    'status' => 'info',
                    'message' => "Already wishlisted."
                ];
            }

        }catch(Exception $e){
            $arr = [
                'status' => 'danger',
                'message' => "Something went wrong! Please try again."
            ];
        }
        return Response()->json($arr);
    }

    /**
    * Remove product from wishlist
    */
    public function removeWishlist(Request $request)
    {
        try{
            $prod = Wishlist::where([
                'user_id' => authUser()->user()->id,
                'product_id' => $request->id,
                'variant_id'=> $request->vid
            ])->first();

            if(!empty($prod) && $prod->delete()){
                $arr = [
                    'status' => 'success',
                    'message' => "Product removed from wishlist successfully."
                ];
            } else {
                $arr = [
                    'status' => 'danger',
                    'message' => "Something went wrong! Please try again."
                ];
            }

        }catch(Exception $e){
            $arr = [
                'status' => 'danger',
                'message' => "Something went wrong! Please try again."
            ];
        }
        return Response()->json($arr);
    }
}
