<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Request;

class ProductFormRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(Request $request)
    {
        $step = !empty($request->get('step'))?$request->get('step'):1;
        if($step == 1){
            return [
                'title' => 'required',
                'arabic_title' => 'required',
                'description' => 'required',
                'arabic_description' => 'required',
                'priority' => 'sometimes|numeric',
                'brand_id' => 'required',
                'category_id' => 'required',
                'sub_category_id' =>'required',
            ];
        }elseif($step == 2){
            return [
                'image' => 'required_if:img_exist,==,0',
                'pid'=> 'required',
            ];
        }elseif($step == 3){
            return [
                'title' => 'required',
                'arabic_title' => 'required',
                'description' => 'required',
                'arabic_description' => 'required',
            ];
        }
    }

    public function messages()
    {
        return [
            'title.required' => __('Title is required'),
            'arabic_title.required' => __('Arabic title is required'),
            'description.required' => __('Description is required'),
            'brand_id.required' => __('Brand is required'),
            'category_id.required' => __('Category is required'),
            'sub_category_id.required' => __('Sub Category is required'),
            'arabic_description.required' => __('Arabic description is required'),
            'image.required' => __('Image is required'),
            'pid.required' => __('Product id is required'),
            'priority.numeric' => __('Priority must have a numeric value'),

        ];
    }
}
