function startAnimation() {
  const CANVAS_WIDTH = window.innerWidth;
  const CANVAS_HEIGHT = window.innerHeight;
  const MIN = 0;
  const MAX = CANVAS_WIDTH;

  const canvas = document.getElementById("canvas");
  const ctx = canvas.getContext("2d");

  canvas.width = CANVAS_WIDTH;
  canvas.height = CANVAS_HEIGHT;

  function clamp(number, min = MIN, max = MAX) {
    return Math.max(min, Math.min(number, max));
  }

  function random(factor) {
    return clamp(Math.floor(Math.random() * factor));
  }

  function degreeToRadian(deg) {
    return deg * (Math.PI / 180);
  }

  // All the properties for Circle
  class Circle {
    xi = CANVAS_WIDTH / 2;
    yi = CANVAS_HEIGHT / 2;
    x = CANVAS_WIDTH / 2;
    y = CANVAS_HEIGHT / 2;
    width = 25;
    r = random(CANVAS_WIDTH);
    deg = 0;
    bgColor = this.randomColor;

    constructor(ctx) {
      this.ctx = ctx;
      this.deg = clamp(Math.floor(Math.random() * 360));
    }

    draw() {
      this.ctx.beginPath();
      this.ctx.fillStyle = this.bgColor;
      this.ctx.arc(this.x, this.y, this.width, 0, 2 * Math.PI);
      this.ctx.fill();
    }

    get randomColor() {
      const r = random(255);
      const g = random(255);
      const b = random(255);
      const rgba = `rgba(${r},${g},${b}, 0.4)`;
      return rgba;
    }
  }

  // Array for storing all the generated circles
  let circles = [];

  // Generate circles
  for (let i = 0; i < 50; i++) {
    circles.push(new Circle(ctx));
  }

  // Clear canvas
  function clearCanvas() {
    ctx.clearRect(0, 0, canvas.width, canvas.height);
  }

  // start and end cordinates of canvas
  let canvasOffset = {
    x0: ctx.canvas.offsetLeft,
    y0: ctx.canvas.offsetTop,
    x1: ctx.canvas.offsetLeft + ctx.canvas.width,
    y1: ctx.canvas.offsetTop + ctx.canvas.height
  };

  function animate() {
    clearCanvas();

    circles.forEach((e) => {
      // reset the circle if it collides on border
      if (
        e.x <= canvasOffset.x0 ||
        e.x >= canvasOffset.x1 ||
        e.y <= canvasOffset.y0 ||
        e.y >= canvasOffset.y1
      ) {
        e.xi = e.x > ctx.canvas.width / 2 ? e.x - 1 : e.x + 1;
        e.yi = e.y > ctx.canvas.height / 2 ? e.y - 1 : e.y + 1;
        e.x = 0;
        e.y = 0;
        e.deg = (e.deg + 60) % 360;
        e.r = 0;
      }

      // Drawing path using polar cordinates
      e.x = e.xi + e.r * Math.cos(degreeToRadian(e.deg));
      e.y = e.yi + e.r * Math.sin(degreeToRadian(e.deg));
      e.r = e.r + 1;
      e.draw();
    });

    requestAnimationFrame(animate);
  }

  animate();
}

startAnimation();

window.addEventListener("resize", startAnimation);