<?php

use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Auth;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\Admin\AdminAuthController;
use App\Http\Controllers\Admin\AdminHomeController;
use App\Http\Controllers\Admin\CategoryController;
use App\Http\Controllers\Admin\ProductController;
use App\Http\Controllers\Admin\UserController;
use App\Http\Controllers\Admin\SubCategoryController;
use App\Http\Controllers\Admin\AttributeController;
use App\Http\Controllers\Admin\AttributeValueController;
use App\Http\Controllers\Admin\CouponController;
use App\Http\Controllers\Admin\GovernorateController;
use App\Http\Controllers\Admin\AreaController;
use App\Http\Controllers\Admin\OrderController;
use App\Http\Controllers\Admin\PageController;
use App\Http\Controllers\Admin\ReportController;
use App\Http\Controllers\Admin\HomeContentController;
use App\Http\Controllers\Admin\BannerController;
use App\Http\Controllers\Admin\RoleController;
use App\Http\Controllers\Admin\PermissionController;
use App\Http\Controllers\Admin\BrandController;
use App\Http\Controllers\Admin\ForgotPasswordController;
use App\Http\Controllers\Admin\NewsLetterController;
use App\Http\Controllers\Admin\SettingsController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\Admin\CareerController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Auth::routes();
// Route::post('/user-login', [LoginController::class,'userlogin'])->name('userLogin');
//Route::get('/logout', [LoginController::class,'logout'])->name('userLogout');

// require 'admin.php';


// Admin Routes
Route::group(['prefix'  =>  'admin'], function () {
    Route::get('/login', [AdminAuthController::class, 'login_form'])->name('admin-login-form');
    Route::post('/submit-login', [AdminAuthController::class, 'login'])->name('admin-login');
    Route::post('/submit-login', [AdminAuthController::class, 'login'])->name('admin-login');
    Route::get('/password/reset', [ForgotPasswordController::class, 'showLinkRequestForm'])->name('admin-password-request');
    Route::post('/password/email', [ForgotPasswordController::class, 'sendResetLinkEmail'])->name('admin-password-email');
    Route::get('/password/reset/{token}/{email}', [ForgotPasswordController::class, 'showResetForm'])->name('admin-password-reset');
    Route::post('/password/reset', [ForgotPasswordController::class, 'resetPassword'])->name('admin-reset-password');


});
Route::group(['prefix' => 'admin',  'middleware' => 'adminauth'], function()
{
    Route::post('/admin/logout', [AdminAuthController::class, 'adminLogout'])->name('adminLogout');
    // Route::get('/home', [AdminHomeController::class, 'index'])->name('admin-home');
    Route::match(['get', 'post'],'/home', [AdminHomeController::class,'index'])->name('admin-home');

    //categories
    Route::get('/categories', [CategoryController::class, 'index'])->name('admin.categories');
    Route::get('/categories/create', [CategoryController::class, 'create'])->name('admin.categories.create');
    Route::post('/categories/store', [CategoryController::class, 'store'])->name('admin.categories.store');
    Route::delete('/categories/{category}', [CategoryController::class, 'destroy'])->name('admin.categories.destroy');
    Route::get('/categories/edit/{category}', [CategoryController::class, 'edit'])->name('admin.categories.edit');
    Route::post('/categories/update/{category_id}', [CategoryController::class, 'update'])->name('admin.categories.update');
    Route::get('/categories/update_status/{id}', [CategoryController::class, 'update_status'])->name('admin.categories.status');

    //sub categories
    Route::get('/sub_categories', [SubCategoryController::class, 'index'])->name('admin.sub_categories');
    Route::get('/sub_categories/create', [SubCategoryController::class, 'create'])->name('admin.sub_categories.create');
    Route::post('/sub_categories/store', [SubCategoryController::class, 'store'])->name('admin.sub_categories.store');
    Route::delete('/sub_categories/{sub_category}', [SubCategoryController::class, 'destroy'])->name('admin.sub_categories.destroy');
    Route::get('/sub_categories/edit/{sub_category}', [SubCategoryController::class, 'edit'])->name('admin.sub_categories.edit');
    Route::post('/sub_categories/update/{sub_category_id}', [SubCategoryController::class, 'update'])->name('admin.sub_categories.update');
    Route::get('/sub_categories/update_status/{id}', [SubCategoryController::class, 'update_status'])->name('admin.sub_categories.status');

    //Products
    Route::get('/product', [ProductController::class, 'index'])->name('admin.product');
    Route::get('/product/create', [ProductController::class, 'create'])->name('admin.product.create');
    Route::post('/product/store', [ProductController::class, 'store'])->name('admin.product.store');
    Route::delete('/product/{product}', [ProductController::class, 'destroy'])->name('admin.product.destroy');
    Route::get('/product/edit/{product}', [ProductController::class, 'edit'])->name('admin.product.edit');
    Route::post('/product/update/{product_id}', [ProductController::class, 'update'])->name('admin.product.update');
    Route::get('/product/update_status/{id}', [ProductController::class, 'update_status'])->name('admin.product.status');
    Route::post('/product/update_variant', [ProductController::class, 'update_variant'])->name('admin.update_variant');
    Route::post('/product/get-subcategory', [ProductController::class, 'getSubcategory'])->name('admin.getSubcategory');

    //users
    Route::get('/users', [UserController::class, 'index'])->name('admin.user');
    Route::get('/user/create', [UserController::class, 'create'])->name('admin.user.create');
    Route::post('/user/store', [UserController::class, 'store'])->name('admin.user.store');
    Route::delete('/user/{user}', [UserController::class, 'destroy'])->name('admin.user.destroy');
    Route::get('/user/edit/{user}', [UserController::class, 'edit'])->name('admin.user.edit');
    Route::post('/user/update/{user_id}', [UserController::class, 'update'])->name('admin.user.update');
    Route::get('/user/update_status/{id}', [UserController::class, 'update_status'])->name('admin.user.status');
    Route::get('/user/addresses/{id}', [UserController::class, 'user_addresses'])->name('admin.user.addresses');

    //Attribute
    Route::get('/attributes', [AttributeController::class, 'index'])->name('admin.attributes');
    Route::get('/attributes/create', [AttributeController::class, 'create'])->name('admin.attributes.create');
    Route::post('/attributes/store', [AttributeController::class, 'store'])->name('admin.attributes.store');
    Route::delete('/attributes/{attribute}', [AttributeController::class, 'destroy'])->name('admin.attributes.destroy');
    Route::get('/attributes/edit/{attribute}', [AttributeController::class, 'edit'])->name('admin.attributes.edit');
    Route::post('/attributes/update/{attribute_id}', [AttributeController::class, 'update'])->name('admin.attributes.update');
    Route::get('/attributes/update_status/{id}', [AttributeController::class, 'update_status'])->name('admin.attributes.status');


    //Attribute Values
    Route::get('/attribute_values', [AttributeValueController::class, 'index'])->name('admin.attribute_values');
    Route::get('/attribute_values/create', [AttributeValueController::class, 'create'])->name('admin.attribute_values.create');
    Route::post('/attribute_values/store', [AttributeValueController::class, 'store'])->name('admin.attribute_values.store');
    Route::delete('/attribute_values/{attribute_value}', [AttributeValueController::class, 'destroy'])->name('admin.attribute_values.destroy');
    Route::get('/attribute_values/edit/{attribute_value}', [AttributeValueController::class, 'edit'])->name('admin.attribute_values.edit');
    Route::post('/attribute_values/update/{attribute_value_id}', [AttributeValueController::class, 'update'])->name('admin.attribute_values.update');
    Route::get('/attribute_values/update_status/{id}', [AttributeValueController::class, 'update_status'])->name('admin.attribute_values.status');


     //Product
     Route::get('/attribute_values', [AttributeValueController::class, 'index'])->name('admin.attribute_values');
     Route::post('/product/get-attribute-value', [ProductController::class, 'get_ajax_attribute_value'])->name('admin.get.attribute.value');
     Route::post('/product/remove-product-image', [ProductController::class, 'remove_ajax_product_image'])->name('admin.remove.product.image');


    //coupon
    Route::get('/coupons', [CouponController::class, 'index'])->name('admin.coupon');
    Route::get('/coupon/create', [CouponController::class, 'create'])->name('admin.coupon.create');
    Route::post('/coupon/store', [CouponController::class, 'store'])->name('admin.coupon.store');
    Route::delete('/coupon/{coupon}', [CouponController::class, 'destroy'])->name('admin.coupon.destroy');
    Route::get('/coupon/edit/{coupon}', [CouponController::class, 'edit'])->name('admin.coupon.edit');
    Route::post('/coupon/update/{coupon_id}', [CouponController::class, 'update'])->name('admin.coupon.update');
    Route::get('/coupon/update_status/{id}', [CouponController::class, 'update_status'])->name('admin.coupon.status');


    //governorate
    Route::get('/governorate', [GovernorateController::class, 'index'])->name('admin.governorate');
    Route::get('/governorate/create', [GovernorateController::class, 'create'])->name('admin.governorate.create');
    Route::post('/governorate/store', [GovernorateController::class, 'store'])->name('admin.governorate.store');
    Route::delete('/governorate/{governorate}', [GovernorateController::class, 'destroy'])->name('admin.governorate.destroy');
    Route::get('/governorate/edit/{governorate}', [GovernorateController::class, 'edit'])->name('admin.governorate.edit');
    Route::post('/governorate/update/{governorate_id}', [GovernorateController::class, 'update'])->name('admin.governorate.update');
    Route::get('/governorate/update_status/{id}', [GovernorateController::class, 'update_status'])->name('admin.governorate.status');


    //Areas
    Route::get('/areas', [AreaController::class, 'index'])->name('admin.areas');
    Route::get('/areas/create', [AreaController::class, 'create'])->name('admin.areas.create');
    Route::post('/areas/store', [AreaController::class, 'store'])->name('admin.areas.store');
    Route::delete('/areas/{area}', [AreaController::class, 'destroy'])->name('admin.areas.destroy');
    Route::get('/areas/edit/{area}', [AreaController::class, 'edit'])->name('admin.areas.edit');
    Route::post('/areas/update/{area_id}', [AreaController::class, 'update'])->name('admin.areas.update');
    Route::get('/areas/update_status/{id}', [AreaController::class, 'update_status'])->name('admin.areas.status');

    //Orders
    Route::get('/orders', [OrderController::class, 'index'])->name('admin.orders');
    Route::get('/order-status/{id}',[OrderController::class,'status'])->name('admin.order.status');
    Route::get('/orders/view/{order}', [OrderController::class, 'view'])->name('admin.order.view');
    Route::post('/orders/update-order-status', [OrderController::class, 'updateOrderStatus'])->name('admin.order.updateOrderStatus');

    //pages
    Route::get('/pages',[PageController::class,'index'])->name('admin.page');
    Route::get('/pages/create',[PageController::class,'create'])->name('admin.page.create');
    Route::post('/pages/store',[PageController::class,'store'])->name('admin.page.store');
    Route::post('/pages/update/{id}',[PageController::class,'update'])->name('admin.page.update');
    Route::get('/pages/edit/{id}',[PageController::class,'edit'])->name('admin.page.edit');
    Route::get('/pages/update_status/{id}',[PageController::class,'update_status'])->name('admin.page.status');

    Route::match(['get', 'post'],'/reports/sales', [ReportController::class,'salesReport'])->name('admin.sales.report');
    Route::match(['get', 'post'],'/reports/area-wise-report', [ReportController::class,'areaWiseReport'])->name('admin.area.report');
    Route::post('/report/get-area-value', [ReportController::class,'filterDefaultAreas'])->name('filter.default.area.dropdown');


    // chartjs data

    Route::post('/filter_area_chart_data', [AdminHomeController::class,'filterAreaChartData'])->name('filter.area.chart.data');


    //Homepage Content managemente
    Route::get('/homecontent/create',[HomeContentController::class,'create'])->name('admin.homecontent.create');
    Route::post('/homecontent/store',[HomeContentController::class,'store'])->name('admin.homecontent.store');
    Route::get('/homecontent/edit/{home_content}', [HomeContentController::class, 'edit'])->name('admin.homecontent.edit');
    Route::post('/homecontent/update/{id}',[HomeContentController::class,'update'])->name('admin.homecontent.update');


     //Banners
     Route::get('/banners', [BannerController::class, 'index'])->name('admin.banner');
     Route::get('/banner/create', [BannerController::class, 'create'])->name('admin.banner.create');
     Route::post('/banner/store', [BannerController::class, 'store'])->name('admin.banner.store');
     Route::delete('/banner/{banner}', [BannerController::class, 'destroy'])->name('admin.banner.destroy');
     Route::get('/banner/edit/{banner}', [BannerController::class, 'edit'])->name('admin.banner.edit');
     Route::post('/banner/update/{banner_id}', [BannerController::class, 'update'])->name('admin.banner.update');
     Route::get('/banner/update_status/{id}', [BannerController::class, 'update_status'])->name('admin.banner.status');

     //Role
    Route::prefix('role')->group(function () {
        Route::get('/index', [RoleController::class, 'index'])->name('role.list');
        Route::get('/create', [RoleController::class, 'create'])->name('role.create');
        Route::post('/store', [RoleController::class, 'store'])->name('role.store');
        Route::get('/edit/{role}', [RoleController::class, 'edit'])->name('role.edit');
        Route::post('/update/{role}', [RoleController::class, 'update'])->name('role.update');
        Route::get('/delete', [RoleController::class, 'destroy'])->name('role.delete');
        Route::get('/ajaxList', [RoleController::class, 'ajaxList'])->name('role.ajaxList');
    });

    //permission
    Route::prefix('permission')->group(function () {
        Route::get('/index', [PermissionController::class, 'index'])->name('permission.list');
        Route::get('/create', [PermissionController::class, 'create'])->name('permission.create');
        Route::post('/store', [PermissionController::class, 'store'])->name('permission.store');
        Route::get('/edit/{permission}', [PermissionController::class, 'edit'])->name('permission.edit');
        Route::post('/update/{permission}', [PermissionController::class, 'update'])->name('permission.update');
        Route::post('/delete', [PermissionController::class, 'destroy'])->name('permission.delete');
        Route::get('/ajaxList', [PermissionController::class, 'ajaxList'])->name('permission.ajaxList');
        Route::get('/ajaxList', [PermissionController::class, 'ajaxList'])->name('permission.ajaxList');
    });

    Route::prefix('role_permission')->group(function () {
        Route::get('/index', [PermissionController::class, 'assign'])->name('role.permission');
        Route::post('/store', [PermissionController::class, 'assignstore'])->name('role.permission.store');
    });

    //Brand
    Route::get('/brands', [BrandController::class, 'index'])->name('admin.brand');
    Route::get('/brand/create', [BrandController::class, 'create'])->name('admin.brand.create');
    Route::post('/brand/store', [BrandController::class, 'store'])->name('admin.brand.store');
    Route::delete('/brand/{brand}', [BrandController::class, 'destroy'])->name('admin.brand.destroy');
    Route::get('/brand/edit/{brand}', [BrandController::class, 'edit'])->name('admin.brand.edit');
    Route::post('/brand/update/{brand_id}', [BrandController::class, 'update'])->name('admin.brand.update');
    Route::get('/brand/update_status/{id}', [BrandController::class, 'update_status'])->name('admin.brand.status');
    Route::post('/brand/deleteImage', [BrandController::class, 'deleteImage'])->name('brand.deleteImage');

    //newsletter
    Route::prefix('newsletter')->group(function() {
        Route::get('/subscribers',[NewsLetterController::class, 'subscribers'])->name('newsletter.subscribers');
        Route::get('/subscribersAjax',[NewsLetterController::class, 'subscribersAjax'])->name('newsletter.subscribersAjax');
        Route::get('/deleteSubscriber',[NewsLetterController::class, 'deleteSubscriber'])->name('newsletter.delete');
        Route::get('/addSubscriber',[NewsLetterController::class, 'addSubscriber'])->name('newsletter.add');
        Route::post('/storeSubscriber',[NewsLetterController::class, 'storeSubscriber'])->name('newsletter.storeSubscriber');

    });

    // Setting
    Route::prefix('settings')->group(function() {
        Route::get('/index', [SettingsController::class, 'index'])->name('settings.list');
        Route::get('/ajaxList', [SettingsController::class, 'ajaxList'])->name('settings.ajaxList');
        Route::get('/create', [SettingsController::class, 'create'])->name('settings.add');
        Route::post('/store', [SettingsController::class, 'store'])->name('settings.store');
        Route::get('/index', [SettingsController::class, 'index'])->name('settings.list');
        Route::get('/edit/{id}', [SettingsController::class, 'edit'])->name('settings.edit');
        Route::get('/view/{id}', [SettingsController::class, 'view'])->name('settings.view');
        Route::post('/update/{id}', [SettingsController::class, 'update'])->name('settings.update');
    });

    //Careers
    Route::prefix('career')->group(function() {
        Route::get('/', [CareerController::class, 'index'])->name('career.list');
        Route::get('/job/', [CareerController::class, 'jobIndex'])->name('job.list');
        Route::get('/job/create', [CareerController::class, 'jobCreate'])->name('job.create');
        Route::post('/job/store', [CareerController::class, 'jobStore'])->name('job.store');
        Route::get('/job/edit/{id}', [CareerController::class, 'jobEdit'])->name('job.edit');
        Route::post('/job/update/{id}', [CareerController::class, 'jobUpdate'])->name('job.update');
        Route::delete('/{career}', [CareerController::class, 'destroy'])->name('career.destroy');
        Route::delete('/job/{job}', [CareerController::class, 'jobDestroy'])->name('job.delete');
        Route::get('/job/update_status/{id}', [CareerController::class, 'update_status'])->name('job.status');
    });

});
//require __DIR__.'/frontend.php';
